import { IdProperty, NameProperty } from '../raw-api/common';
import { Attachment } from './attachment';
import { AvatarUrls } from './avatarUrls';
import { Comment } from './comment';
import { FieldMeta } from './field_meta';
import { HistoryMetadata } from './history_metadata';
import { IssueLinkType } from './issue_link_type';
import { IssueRef } from './issue_ref';
import { IssueType } from './issue_type';
import { JsonType } from './json_type';
import { LinkGroup } from './link_group';
import { Priority } from './priority';
import { Status } from './status';
import { Transition } from './transition';
import { Worklog } from './worklog';
interface CommonFields {
    components?: IdProperty[];
    reporter?: NameProperty;
    description?: string;
    assignee?: NameProperty;
    fixVersions?: IdProperty[];
    priority?: IdProperty;
    labels?: string[];
    versions?: IdProperty[];
    duedate?: string;
    security?: IdProperty;
    timetracking?: {
        remainingEstimate?: string;
        originalEstimate?: string;
    };
    environment?: string;
    parent?: {
        id?: string;
        key?: string;
    };
}
export interface FieldsCreateIssue extends CommonFields {
    project: IdProperty;
    issuetype: IdProperty;
    summary: string;
}
export interface FieldsEditIssue extends CommonFields {
    project?: IdProperty;
    issuetype?: IdProperty;
    summary?: string;
    resolution?: IdProperty;
}
export interface IssueResponse {
    expand?: string;
    id?: string;
    self?: string;
    key?: string;
    fields?: {
        issuetype?: IssueType;
        components?: {
            self?: string;
            id?: string;
            name?: string;
            description?: string;
        }[];
        timespent?: number;
        timeoriginalestimate?: number;
        description?: string;
        project?: {
            self?: string;
            id?: string;
            key?: string;
            name?: string;
            avatarUrls?: AvatarUrls;
        };
        fixVersions?: {
            self?: string;
            id?: string;
            description?: string;
            name?: string;
            archived?: boolean;
            released?: boolean;
        }[];
        aggregatetimespent?: number;
        resolution?: {
            self?: string;
            id?: string;
            description?: string;
            name?: string;
        };
        timetracking?: {
            originalEstimate?: string;
            remainingEstimate?: string;
            timeSpent?: string;
            originalEsimateSeconds?: number;
            remainingEstimateSeconds?: number;
            timeSpentSeconds?: number;
        };
        subtasks?: IssueRef[];
        attachment?: Attachment[];
        aggregatetimeestimate?: number;
        resolutiondate?: string;
        workratio?: number;
        summary?: string;
        lastViewed?: any;
        watches?: {
            self?: string;
            watchCount?: number;
            isWatching?: boolean;
        };
        creator?: {
            self?: string;
            name?: string;
            key?: string;
            emailAddress?: string;
            avatarUrls?: AvatarUrls;
            displayName?: string;
            active?: boolean;
            timeZone?: string;
        };
        created?: string;
        reporter?: {
            self?: string;
            name?: string;
            key?: string;
            emailAddress?: string;
            avatarUrls?: AvatarUrls;
            displayName?: string;
            active?: boolean;
            timeZone?: string;
        };
        aggregateprogress?: {
            progress?: number;
            total?: number;
            percent?: number;
        };
        priority?: Priority;
        labels?: string[];
        environment?: string;
        timeestimate?: number;
        aggregatetimeoriginalestimate?: number;
        versions?: {
            self?: string;
            id?: string;
            description?: string;
            name?: string;
            archived?: boolean;
            released?: boolean;
        }[];
        duedate?: string;
        progress?: {
            progress?: number;
            total?: number;
            percent?: number;
        };
        comment?: {
            comments?: Comment[];
            maxResults?: number;
            total?: number;
            startAt?: number;
        };
        issuelinks?: {
            id?: string;
            self?: string;
            type?: IssueLinkType;
            inwardIssue?: {
                summary?: string;
                status?: Status;
                priority?: Priority;
                issuetype?: IssueType;
            };
        }[];
        votes?: {
            self?: string;
            votes?: number;
            hasVoted?: boolean;
        };
        worklog?: {
            startAt?: number;
            maxResults?: number;
            total?: number;
            worklogs?: Worklog[];
        };
        assignee?: {
            self?: string;
            name?: string;
            key?: string;
            emailAddress?: string;
            avatarUrls?: AvatarUrls;
            displayName?: string;
            active?: boolean;
            timeZone?: string;
        };
        updated?: string;
        status?: Status;
        parent?: IssueRef;
    };
    renderedFields?: Record<string, any>;
    properties?: {
        properties: Record<string, string>;
    };
    names?: Record<string, string>;
    schema?: Record<string, JsonType>;
    transitions?: Transition[];
    operations?: {
        linkGroups?: LinkGroup[];
    };
    editmeta?: {
        fields?: Record<string, FieldMeta>;
    };
    changelog?: {
        startAt?: number;
        maxResults?: number;
        total?: number;
        histories?: {
            id?: string;
            author?: {
                active: boolean;
                self?: string;
                key?: string;
                name?: string;
                emailAddress?: string;
                avatarUrls?: AvatarUrls;
                displayName?: string;
                timeZone?: string;
                locale?: string;
            };
            created?: string;
            items?: {
                field?: string;
                fieldtype?: string;
                from?: string;
                fromString?: string;
                to?: string;
                toString?: string;
            }[];
            historyMetadata?: HistoryMetadata;
        }[];
    };
    versionedRepresentations?: Record<string, Record<string, any>>;
    fieldsToInclude?: any;
}
export {};
//# sourceMappingURL=issue.d.ts.map