import { executeRequest } from './common';
import { getAllDashboards as getAllDashboardsFn, getDashboardById as getDashboardByIdFn } from '../raw-api/dashboard';
/**
 * Returns a list of all dashboards, optionally filtering them.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/dashboard-list
 * @param options Request options.
 */
export function getAllDashboards(options) {
    return executeRequest(() => getAllDashboardsFn(options), options.errorStrategy);
}
/**
 * Returns a single dashboard.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/dashboard-getDashboard
 * @param options Request options.
 */
export function getDashboardById(options) {
    return executeRequest(() => getDashboardByIdFn(options), options.errorStrategy);
}
