import { Filter } from '../types/filter';
/**
 * Returns a filter given an id.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getFilter
 * @param options Request options.
 */
export declare function getFilter<T = Filter.GetFilter.Response.OK>(options: Filter.GetFilter.Options.HandledApi): Promise<import("../definitions/filter").Filter>;
/**
 * Returns the favourite filters of the logged-in user.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getFavouriteFilters
 * @param options Request options.
 */
export declare function getMyFavouriteFilters<T = Filter.GetMyFavouriteFilters.Response.OK>(options: Filter.GetMyFavouriteFilters.Options.HandledApi): Promise<Filter.GetMyFavouriteFilters.Response.OK>;
/**
 * Creates a new filter, and returns newly created filter. Currently sets permissions just using the users default sharing permissions.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-createFilter
 * @param options Request options.
 */
export declare function createFilter<T = Filter.CreateFilter.Response.OK>(options: Filter.CreateFilter.Options.HandledApi): Promise<import("../definitions/filter").Filter>;
/**
 * Updates an existing filter, and returns its new value.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-editFilter
 * @param options Request options.
 */
export declare function editFilter<T = Filter.EditFilter.Response.OK>(options: Filter.EditFilter.Options.HandledApi): Promise<import("../definitions/filter").Filter>;
/**
 * Delete a filter.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-deleteFilter
 * @param options Request options.
 */
export declare function deleteFilter<T = Filter.DeleteFilter.Response.OK>(options: Filter.DeleteFilter.Options.HandledApi): Promise<undefined>;
//# sourceMappingURL=filter.d.ts.map