import { executeRequest } from './common';
import { getFilter as getFilterFn, getMyFavouriteFilters as getMyFavouriteFiltersFn, createFilter as createFilterFn, editFilter as editFilterFn, deleteFilter as deleteFilterFn } from '../raw-api/filter';
/**
 * Returns a filter given an id.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getFilter
 * @param options Request options.
 */
export function getFilter(options) {
    return executeRequest(() => getFilterFn(options), options.errorStrategy);
}
/**
 * Returns the favourite filters of the logged-in user.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getFavouriteFilters
 * @param options Request options.
 */
export function getMyFavouriteFilters(options) {
    return executeRequest(() => getMyFavouriteFiltersFn(options), options.errorStrategy);
}
/**
 * Creates a new filter, and returns newly created filter. Currently sets permissions just using the users default sharing permissions.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-createFilter
 * @param options Request options.
 */
export function createFilter(options) {
    return executeRequest(() => createFilterFn(options), options.errorStrategy);
}
/**
 * Updates an existing filter, and returns its new value.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-editFilter
 * @param options Request options.
 */
export function editFilter(options) {
    return executeRequest(() => editFilterFn(options), options.errorStrategy);
}
/**
 * Delete a filter.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-deleteFilter
 * @param options Request options.
 */
export function deleteFilter(options) {
    return executeRequest(() => deleteFilterFn(options), options.errorStrategy);
}
