import { executeRequest } from '../common';
import { getFilterDefaultColumns as getFilterDefaultColumnsFn, setFilterDefaultColumns as setFilterDefaultColumnsFn, resetFilterColumns as resetFilterColumnsFn } from '../../raw-api/filter/column';
/**
 * Returns the default columns for the given filter. Currently logged in user will be used as the user making such request.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-defaultColumns
 * @param options Request options.
 */
export function getFilterDefaultColumns(options) {
    return executeRequest(() => getFilterDefaultColumnsFn(options), options.errorStrategy);
}
/**
 * Sets the default columns for the given filter.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-setColumns
 * @param options Request options.
 */
export function setFilterDefaultColumns(options) {
    return executeRequest(() => setFilterDefaultColumnsFn(options), options.errorStrategy);
}
/**
 * Resets the columns for the given filter such that the filter no longer has its own column config.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-resetColumns
 * @param options Request options.
 */
export function resetFilterColumns(options) {
    return executeRequest(() => resetFilterColumnsFn(options), options.errorStrategy);
}
