import { executeRequest } from '../common';
import { getDefaultShareScope as getDefaultShareScopeFn, setDefaultShareScope as setDefaultShareScopeFn } from '../../raw-api/filter/share';
/**
 * Returns the default share scope of the logged-in user.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getDefaultShareScope
 * @param options Request options.
 */
export function getDefaultShareScope(options) {
    return executeRequest(() => getDefaultShareScopeFn(options), options.errorStrategy);
}
/**
 * Sets the default share scope of the logged-in user. Available values are GLOBAL and PRIVATE.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-setDefaultShareScope
 * @param options Request options.
 */
export function setDefaultShareScope(options) {
    return executeRequest(() => setDefaultShareScopeFn(options), options.errorStrategy);
}
