import { executeRequest } from '../../common';
import { getFilterSharePermissions as getFilterSharePermissionsFn, addFilterSharePermission as addFilterSharePermissionFn, getFilterSharePermission as getFilterSharePermissionFn, deleteFilterSharePermission as deleteFilterSharePermissionFn } from '../../../raw-api/filter/share/permission';
/**
 * Returns all share permissions of the given filter.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getSharePermissions
 * @param options Request options.
 */
export function getFilterSharePermissions(options) {
    return executeRequest(() => getFilterSharePermissionsFn(options), options.errorStrategy);
}
/**
 * Adds a share permissions to the given filter. Adding a global permission removes all previous permissions from the filter.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-addSharePermission
 * @param options Request options.
 */
export function addFilterSharePermission(options) {
    return executeRequest(() => addFilterSharePermissionFn(options), options.errorStrategy);
}
/**
 * Returns a single share permission of the given filter.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getSharePermission
 * @param options Request options.
 */
export function getFilterSharePermission(options) {
    return executeRequest(() => getFilterSharePermissionFn(options), options.errorStrategy);
}
/**
 * Removes a share permissions from the given filter.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getSharePermission
 * @param options Request options.
 */
export function deleteFilterSharePermission(options) {
    return executeRequest(() => deleteFilterSharePermissionFn(options), options.errorStrategy);
}
