import { executeRequest } from '../common';
import { getUsersFromGroup as getUsersFromGroupFn, addUsersToGroup as addUsersToGroupFn, removeUsersFromGroup as removeUsersFromGroupFn } from '../../raw-api/group/user';
/**
 * This resource returns a paginated list of users who are members of the specified group and its subgroups. Users in the page are ordered by user names. User of this resource is required to have sysadmin or admin permissions.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/group-getUsersFromGroup
 * @param options Request options.
 */
export function getUsersFromGroup(options) {
    return executeRequest(() => getUsersFromGroupFn(options), options.errorStrategy);
}
/**
 * Adds given user to a group.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/group-addUserToGroup
 * @param options Request options.
 */
export function addUsersToGroup(options) {
    return executeRequest(() => addUsersToGroupFn(options), options.errorStrategy);
}
/**
 * Removes given user from a group.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/group-removeUserFromGroup
 * @param options Request options.
 */
export function removeUsersFromGroup(options) {
    return executeRequest(() => removeUsersFromGroupFn(options), options.errorStrategy);
}
