import { executeRequest } from './common';
import { getApplicationProperty as getApplicationPropertyFn, setApplicationProperty as setApplicationPropertyFn, getAdvancedSettings as getAdvancedSettingsFn, getInstanceConfiguration as getInstanceConfigurationFn, getInstanceInfo as getInstanceInfoFn } from '../raw-api/instance';
/**
 * Returns an application property.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/application-properties-getProperty
 * @param options Request options.
 */
export function getApplicationProperty(options) {
    return executeRequest(() => getApplicationPropertyFn(options), options.errorStrategy);
}
/**
 * Modify an application property via PUT. The "value" field present in the PUT will override the existing value.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/application-properties-setPropertyViaRestfulTable
 * @param options Request options.
 */
export function setApplicationProperty(options) {
    return executeRequest(() => setApplicationPropertyFn(options), options.errorStrategy);
}
/**
 * Returns the properties that are displayed on the "General Configuration > Advanced Settings" page.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/application-properties-getAdvancedSettings
 * @param options Request options.
 */
export function getAdvancedSettings(options) {
    return executeRequest(() => getAdvancedSettingsFn(options), options.errorStrategy);
}
/**
 * Returns the information if the optional features in JIRA are enabled or disabled. If the time tracking is enabled, it also returns the detailed information about time tracking configuration.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/configuration-getConfiguration
 * @param options Request options.
 */
export function getInstanceConfiguration(options) {
    return executeRequest(() => getInstanceConfigurationFn(options), options.errorStrategy);
}
/**
 * Returns general information about the current JIRA server.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/serverInfo-getServerInfo
 * @param options Request options.
 */
export function getInstanceInfo(options) {
    return executeRequest(() => getInstanceInfoFn(options), options.errorStrategy);
}
