import { executeRequest } from '../common';
import { getIssueAttachment as getIssueAttachmentFn, removeIssueAttachment as removeIssueAttachmentFn, addIssueAttachment as addIssueAttachmentFn } from '../../raw-api/issue/attachment';
/**
 * Returns the meta-data for an attachment, including the URI of the actual attached file.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/attachment-getAttachment
 * @param options Request options.
 */
export function getIssueAttachment(options) {
    return executeRequest(() => getIssueAttachmentFn(options), options.errorStrategy);
}
/**
 * Remove an attachment from an issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/attachment-removeAttachment
 * @param options Request options.
 */
export function removeIssueAttachment(options) {
    return executeRequest(() => removeIssueAttachmentFn(options), options.errorStrategy);
}
/**
 * Add one or more attachments to an issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue/{issueIdOrKey}/attachments-addAttachment
 * @param options Request options.
 */
export function addIssueAttachment(options) {
    return executeRequest(() => addIssueAttachmentFn(options), options.errorStrategy);
}
