import { executeRequest } from '../common';
import { addIssueComment as addIssueCommentFn, getIssueComments as getIssueCommentsFn, getIssueComment as getIssueCommentFn, updateIssueComment as updateIssueCommentFn, deleteIssueComment as deleteIssueCommentFn } from '../../raw-api/issue/comment';
/**
 * Returns all comments for an issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getComments
 * @param options Request options.
 */
export function getIssueComments(options) {
    return executeRequest(() => getIssueCommentsFn(options), options.errorStrategy);
}
/**
 * Adds a new comment to an issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-addComment
 * @param options Request options.
 */
export function addIssueComment(options) {
    return executeRequest(() => addIssueCommentFn(options), options.errorStrategy);
}
/**
 * Returns a single comment.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getComment
 * @param options Request options.
 */
export function getIssueComment(options) {
    return executeRequest(() => getIssueCommentFn(options), options.errorStrategy);
}
/**
 * Updates an existing comment using its JSON representation.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-updateComment
 * @param options Request options.
 */
export function updateIssueComment(options) {
    return executeRequest(() => updateIssueCommentFn(options), options.errorStrategy);
}
/**
 * Deletes an existing comment.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteComment
 * @param options Request options.
 */
export function deleteIssueComment(options) {
    return executeRequest(() => deleteIssueCommentFn(options), options.errorStrategy);
}
