import { Issue } from '../../types/issue';
/**
 * Creates an issue link between two issues. The user requires the link issue permission for the issue which will be linked to another issue. The specified link type in the request is used to create the link and will create a link from the first issue to the second issue using the outward description. It also create a link from the second issue to the first issue using the inward description of the issue link type. It will add the supplied comment to the first issue. The comment can have a restriction who can view it. If group is specified, only users of this group can view this comment, if roleLevel is specified only users who have the specified role can view this comment. The user who creates the issue link needs to belong to the specified group or have the specified role.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLink-linkIssues
 * @param options Request options.
 */
export declare function createIssueLink<T = Issue.Link.CreateLink.Response.OK>(options: Issue.Link.CreateLink.Options.HandledApi): Promise<undefined>;
/**
 * Returns an issue link with the specified id.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLink-getIssueLink
 * @param options Request options.
 */
export declare function getIssueLink<T = Issue.Link.GetLink.Response.OK>(options: Issue.Link.GetLink.Options.HandledApi): Promise<Issue.Link.GetLink.Response.OK>;
/**
 * Deletes an issue link with the specified id. To be able to delete an issue link you must be able to view both issues and must have the link issue permission for at least one of the issues.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLink-deleteIssueLink
 * @param options Request options.
 */
export declare function deleteIssueLink<T = Issue.Link.DeleteLink.Response.OK>(options: Issue.Link.DeleteLink.Options.HandledApi): Promise<undefined>;
//# sourceMappingURL=link.d.ts.map