import { Issue } from '../../../types/issue';
/**
 * A REST sub-resource representing the remote issue links on the issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getRemoteIssueLinks
 * @param options Request options.
 */
export declare function getRemoteIssueLinks<T = Issue.Link.Remote.GetLinks.Response.OK>(options: Issue.Link.Remote.GetLinks.Options.HandledApi): Promise<Issue.Link.Remote.GetLinks.Response.OK>;
/**
 * Creates or updates a remote issue link from a JSON representation. If a globalId is provided and a remote issue link exists with that globalId, the remote issue link is updated. Otherwise, the remote issue link is created.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-createOrUpdateRemoteIssueLink
 * @param options Request options.
 */
export declare function createOrUpdateRemoteIssueLink<T = Issue.Link.Remote.CreateOrUpdateLink.Response.OK>(options: Issue.Link.Remote.CreateOrUpdateLink.Options.HandledApi): Promise<Issue.Link.Remote.CreateOrUpdateLink.Response.OK>;
/**
 * Delete the remote issue link with the given global id on the issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteRemoteIssueLinkByGlobalId
 * @param options Request options.
 */
export declare function deleteRemoteIssueLinkByGlobalId<T = Issue.Link.Remote.DeleteLinkByGlobalId.Response.OK>(options: Issue.Link.Remote.DeleteLinkByGlobalId.Options.HandledApi): Promise<undefined>;
/**
 * Get the remote issue link with the given id on the issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getRemoteIssueLinkById
 * @param options Request options.
 */
export declare function getRemoteIssueLink<T = Issue.Link.Remote.GetLink.Response.OK>(options: Issue.Link.Remote.GetLink.Options.HandledApi): Promise<Issue.Link.Remote.GetLink.Response.OK>;
/**
 * Updates a remote issue link from a JSON representation. Any fields not provided are set to null.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-updateRemoteIssueLink
 * @param options Request options.
 */
export declare function updateRemoteIssueLink<T = Issue.Link.Remote.UpdateLink.Response.OK>(options: Issue.Link.Remote.UpdateLink.Options.HandledApi): Promise<undefined>;
/**
 * Delete the remote issue link with the given id on the issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteRemoteIssueLinkById
 * @param options Request options.
 */
export declare function deleteRemoteIssueLink<T = Issue.Link.Remote.DeleteLink.Response.OK>(options: Issue.Link.Remote.DeleteLink.Options.HandledApi): Promise<undefined>;
//# sourceMappingURL=remote.d.ts.map