import { executeRequest } from '../../common';
import { getRemoteIssueLinks as getRemoteIssueLinksFn, createOrUpdateRemoteIssueLink as createOrUpdateRemoteIssueLinkFn, deleteRemoteIssueLinkByGlobalId as deleteRemoteIssueLinkByGlobalIdFn, getRemoteIssueLink as getRemoteIssueLinkFn, updateRemoteIssueLink as updateRemoteIssueLinkFn, deleteRemoteIssueLink as deleteRemoteIssueLinkFn } from '../../../raw-api/issue/link/remote';
/**
 * A REST sub-resource representing the remote issue links on the issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getRemoteIssueLinks
 * @param options Request options.
 */
export function getRemoteIssueLinks(options) {
    return executeRequest(() => getRemoteIssueLinksFn(options), options.errorStrategy);
}
/**
 * Creates or updates a remote issue link from a JSON representation. If a globalId is provided and a remote issue link exists with that globalId, the remote issue link is updated. Otherwise, the remote issue link is created.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-createOrUpdateRemoteIssueLink
 * @param options Request options.
 */
export function createOrUpdateRemoteIssueLink(options) {
    return executeRequest(() => createOrUpdateRemoteIssueLinkFn(options), options.errorStrategy);
}
/**
 * Delete the remote issue link with the given global id on the issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteRemoteIssueLinkByGlobalId
 * @param options Request options.
 */
export function deleteRemoteIssueLinkByGlobalId(options) {
    return executeRequest(() => deleteRemoteIssueLinkByGlobalIdFn(options), options.errorStrategy);
}
/**
 * Get the remote issue link with the given id on the issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getRemoteIssueLinkById
 * @param options Request options.
 */
export function getRemoteIssueLink(options) {
    return executeRequest(() => getRemoteIssueLinkFn(options), options.errorStrategy);
}
/**
 * Updates a remote issue link from a JSON representation. Any fields not provided are set to null.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-updateRemoteIssueLink
 * @param options Request options.
 */
export function updateRemoteIssueLink(options) {
    return executeRequest(() => updateRemoteIssueLinkFn(options), options.errorStrategy);
}
/**
 * Delete the remote issue link with the given id on the issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteRemoteIssueLinkById
 * @param options Request options.
 */
export function deleteRemoteIssueLink(options) {
    return executeRequest(() => deleteRemoteIssueLinkFn(options), options.errorStrategy);
}
