import { Issue } from '../../../types/issue';
/**
 * Returns a list of available issue link types, if issue linking is enabled. Each issue link type has an id, a name and a label for the outward and inward link relationship.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-getIssueLinkTypes
 * @param options Request options.
 */
export declare function getIssueLinkTypes<T = Issue.Link.Type.GetTypes.Response.OK>(options: Issue.Link.Type.GetTypes.Options.HandledApi): Promise<Issue.Link.Type.GetTypes.Response.OK>;
/**
 * Returns for a given issue link type id all information about this issue link type.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-getIssueLinkType
 * @param options Request options.
 */
export declare function getIssueLinkType<T = Issue.Link.Type.GetType.Response.OK>(options: Issue.Link.Type.GetType.Options.HandledApi): Promise<import("../../../definitions/issue_link_type").IssueLinkType>;
/**
 * Create a new issue link type.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-createIssueLinkType
 * @param options Request options.
 */
export declare function createIssueLinkType<T = Issue.Link.Type.CreateType.Response.OK>(options: Issue.Link.Type.CreateType.Options.HandledApi): Promise<import("../../../definitions/issue_link_type").IssueLinkType>;
/**
 * Delete the specified issue link type.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-deleteIssueLinkType
 * @param options Request options.
 */
export declare function deleteIssueLinkType<T = Issue.Link.Type.DeleteType.Response.OK>(options: Issue.Link.Type.DeleteType.Options.HandledApi): Promise<undefined>;
/**
 * Update the specified issue link type.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-updateIssueLinkType
 * @param options Request options.
 */
export declare function updateIssueLinkType<T = Issue.Link.Type.UpdateType.Response.OK>(options: Issue.Link.Type.UpdateType.Options.HandledApi): Promise<import("../../../definitions/issue_link_type").IssueLinkType>;
//# sourceMappingURL=type.d.ts.map