import { executeRequest } from '../../common';
import { getIssueLinkTypes as getIssueLinkTypesFn, getIssueLinkType as getIssueLinkTypeFn, createIssueLinkType as createIssueLinkTypeFn, deleteIssueLinkType as deleteIssueLinkTypeFn, updateIssueLinkType as updateIssueLinkTypeFn } from '../../../raw-api/issue/link/type';
/**
 * Returns a list of available issue link types, if issue linking is enabled. Each issue link type has an id, a name and a label for the outward and inward link relationship.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-getIssueLinkTypes
 * @param options Request options.
 */
export function getIssueLinkTypes(options) {
    return executeRequest(() => getIssueLinkTypesFn(options), options.errorStrategy);
}
/**
 * Returns for a given issue link type id all information about this issue link type.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-getIssueLinkType
 * @param options Request options.
 */
export function getIssueLinkType(options) {
    return executeRequest(() => getIssueLinkTypeFn(options), options.errorStrategy);
}
/**
 * Create a new issue link type.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-createIssueLinkType
 * @param options Request options.
 */
export function createIssueLinkType(options) {
    return executeRequest(() => createIssueLinkTypeFn(options), options.errorStrategy);
}
/**
 * Delete the specified issue link type.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-deleteIssueLinkType
 * @param options Request options.
 */
export function deleteIssueLinkType(options) {
    return executeRequest(() => deleteIssueLinkTypeFn(options), options.errorStrategy);
}
/**
 * Update the specified issue link type.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-updateIssueLinkType
 * @param options Request options.
 */
export function updateIssueLinkType(options) {
    return executeRequest(() => updateIssueLinkTypeFn(options), options.errorStrategy);
}
