import { executeRequest } from '../common';
import { getIssuePriorities as getIssuePrioritiesFn, getIssuePriority as getIssuePriorityFn } from '../../raw-api/issue/priority';
/**
 * Returns a list of all issue priorities.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/priority-getPriorities
 * @param options Request options.
 */
export function getIssuePriorities(options) {
    return executeRequest(() => getIssuePrioritiesFn(options), options.errorStrategy);
}
/**
 * Returns an issue priority.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/priority-getPriority
 * @param options Request options.
 */
export function getIssuePriority(options) {
    return executeRequest(() => getIssuePriorityFn(options), options.errorStrategy);
}
