import { executeRequest } from '../common';
import { getIssueSubTasks as getIssueSubTasksFn, canMoveIssueSubTask as canMoveIssueSubTaskFn, moveIssueSubTasks as moveIssueSubTasksFn } from '../../raw-api/issue/subTask';
/**
 * Returns an issue's subtask list.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue/{issueIdOrKey}/subtask-getSubTasks
 * @param options Request options.
 */
export function getIssueSubTasks(options) {
    return executeRequest(() => getIssueSubTasksFn(options), options.errorStrategy);
}
/**
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue/{issueIdOrKey}/subtask-canMoveSubTask
 * @param options Request options.
 */
export function canMoveIssueSubTask(options) {
    return executeRequest(() => canMoveIssueSubTaskFn(options), options.errorStrategy);
}
/**
 * Reorders an issue's subtasks by moving the subtask at index "from" to index "to".
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue/{issueIdOrKey}/subtask-moveSubTasks
 * @param options Request options.
 */
export function moveIssueSubTasks(options) {
    return executeRequest(() => moveIssueSubTasksFn(options), options.errorStrategy);
}
