import { executeRequest } from '../common';
import { getIssueTypes as getIssueTypesFn, getIssueType as getIssueTypeFn, createIssueType as createIssueTypeFn, deleteIssueType as deleteIssueTypeFn, updateIssueType as updateIssueTypeFn, getAlternativeIssueTypes as getAlternativeIssueTypesFn } from '../../raw-api/issue/type';
/**
 * Returns a list of all issue types visible to the user.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-getIssueAllTypes
 * @param options Request options.
 */
export function getIssueTypes(options) {
    return executeRequest(() => getIssueTypesFn(options), options.errorStrategy);
}
/**
 * Returns a full representation of the issue type that has the given id.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-getIssueType
 * @param options Request options.
 */
export function getIssueType(options) {
    return executeRequest(() => getIssueTypeFn(options), options.errorStrategy);
}
/**
 * Creates an issue type from a JSON representation and adds the issue newly created issue type to the default issue type scheme.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-createIssueType
 * @param options Request options.
 */
export function createIssueType(options) {
    return executeRequest(() => createIssueTypeFn(options), options.errorStrategy);
}
/**
 * Deletes the specified issue type. If the issue type has any associated issues, these issues will be migrated to the alternative issue type specified in the parameter.
 * You can determine the alternative issue types by calling the /rest/api/2/issuetype/{id}/alternatives resource.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-deleteIssueType
 * @param options Request options.
 */
export function deleteIssueType(options) {
    return executeRequest(() => deleteIssueTypeFn(options), options.errorStrategy);
}
/**
 * Updates the specified issue type from a JSON representation.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-updateIssueType
 * @param options Request options.
 */
export function updateIssueType(options) {
    return executeRequest(() => updateIssueTypeFn(options), options.errorStrategy);
}
/**
 * Returns a list of all alternative issue types for the given issue type id. The list will contain these issues types, to which issues assigned to the given issue type can be migrated.
 * The suitable alternatives are issue types which are assigned to the same workflow, the same field configuration and the same screen scheme.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-getAlternativeIssueTypes
 * @param options Request options.
 */
export function getAlternativeIssueTypes(options) {
    return executeRequest(() => getAlternativeIssueTypesFn(options), options.errorStrategy);
}
