import { executeRequest } from '../common';
import { removeIssueVote as removeIssueVoteFn, addIssueVote as addIssueVoteFn, getIssueVotes as getIssueVotesFn } from '../../raw-api/issue/vote';
/**
 * Remove your vote from an issue. (i.e. "unvote").
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-removeVote
 * @param options Request options.
 */
export function removeIssueVote(options) {
    return executeRequest(() => removeIssueVoteFn(options), options.errorStrategy);
}
/**
 * Cast your vote in favour of an issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-addVote
 * @param options Request options.
 */
export function addIssueVote(options) {
    return executeRequest(() => addIssueVoteFn(options), options.errorStrategy);
}
/**
 * A REST sub-resource representing the voters on the issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getVotes
 * @param options Request options.
 */
export function getIssueVotes(options) {
    return executeRequest(() => getIssueVotesFn(options), options.errorStrategy);
}
