import { executeRequest } from '../common';
import { getIssueWatchers as getIssueWatchersFn, addIssueWatcher as addIssueWatcherFn, removeIssueWatcher as removeIssueWatcherFn } from '../../raw-api/issue/watcher';
/**
 * Returns the list of watchers for the issue with the given key.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getIssueWatchers
 * @param options Request options.
 */
export function getIssueWatchers(options) {
    return executeRequest(() => getIssueWatchersFn(options), options.errorStrategy);
}
/**
 * Adds a user to an issue's watcher list.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-addWatcher
 * @param options Request options.
 */
export function addIssueWatcher(options) {
    return executeRequest(() => addIssueWatcherFn(options), options.errorStrategy);
}
/**
 * Removes a user from an issue's watcher list.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-removeWatcher
 * @param options Request options.
 */
export function removeIssueWatcher(options) {
    return executeRequest(() => removeIssueWatcherFn(options), options.errorStrategy);
}
