import { Issue } from '../../types/issue';
/**
 * Returns all work logs for an issue. Work logs won't be returned if the Log work field is hidden for the project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getIssueWorklog
 * @param options Request options.
 */
export declare function getIssueWorklogs<T = Issue.Worklog.GetWorklogs.Response.OK>(options: Issue.Worklog.GetWorklogs.Options.HandledApi): Promise<Issue.Worklog.GetWorklogs.Response.OK>;
/**
 * Adds a new worklog entry to an issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-addWorklog
 * @param options Request options.
 */
export declare function addIssueWorklog<T = Issue.Worklog.AddWorklog.Response.OK>(options: Issue.Worklog.AddWorklog.Options.HandledApi): Promise<import("../../definitions/worklog").Worklog>;
/**
 * Returns a specific worklog. The work log won't be returned if the Log work field is hidden for the project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getWorklog
 * @param options Request options.
 */
export declare function getIssueWorklog<T = Issue.Worklog.GetWorklog.Response.OK>(options: Issue.Worklog.GetWorklog.Options.HandledApi): Promise<import("../../definitions/worklog").Worklog>;
/**
 * Updates an existing worklog entry. Fields possible for editing are: comment, visibility, started, timeSpent and timeSpentSeconds. Either timeSpent or timeSpentSeconds can be set. Fields which are not set will not be updated. For a request to be valid, it has to have at least one field change.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-updateWorklog
 * @param options Request options.
 */
export declare function updateIssueWorklog<T = Issue.Worklog.UpdateWorklog.Response.OK>(options: Issue.Worklog.UpdateWorklog.Options.HandledApi): Promise<import("../../definitions/worklog").Worklog>;
/**
 * Deletes an existing worklog entry.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteWorklog
 * @param options Request options.
 */
export declare function deleteIssueWorklog<T = Issue.Worklog.DeleteWorklog.Response.OK>(options: Issue.Worklog.DeleteWorklog.Options.HandledApi): Promise<undefined>;
/**
 * Returns worklogs id and delete time of worklogs that was deleted since given time. The returns set of worklogs is limited to 1000 elements. This API will not return worklogs deleted during last minute.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/worklog-getIdsOfWorklogsDeletedSince
 * @param options Request options.
 */
export declare function getDeletedIssueWorklogIds<T = Issue.Worklog.GetDeletedWorklogIds.Response.OK>(options: Issue.Worklog.GetDeletedWorklogIds.Options.HandledApi): Promise<Issue.Worklog.GetDeletedWorklogIds.Response.OK>;
/**
 * Returns worklogs for given worklog ids. Only worklogs to which the calling user has permissions, will be included in the result. The returns set of worklogs is limited to 1000 elements.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/worklog-getWorklogsForIds
 * @param options Request options.
 */
export declare function getIssueWorklogsForIds<T = Issue.Worklog.GetWorklogsForIds.Response.OK>(options: Issue.Worklog.GetWorklogsForIds.Options.HandledApi): Promise<Issue.Worklog.GetWorklogsForIds.Response.OK>;
/**
 * Returns worklogs id and update time of worklogs that was updated since given time. The returns set of worklogs is limited to 1000 elements. This API will not return worklogs updated during last minute.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/worklog-getIdsOfWorklogsModifiedSince
 * @param options Request options.
 */
export declare function getUpdatedIssueWorklogIds<T = Issue.Worklog.GetUpdatedWorklogIds.Response.OK>(options: Issue.Worklog.GetUpdatedWorklogIds.Options.HandledApi): Promise<Issue.Worklog.GetUpdatedWorklogIds.Response.OK>;
//# sourceMappingURL=worklog.d.ts.map