import { executeRequest } from '../common';
import { getIssueWorklogs as getIssueWorklogsFn, addIssueWorklog as addIssueWorklogFn, getIssueWorklog as getIssueWorklogFn, updateIssueWorklog as updateIssueWorklogFn, deleteIssueWorklog as deleteIssueWorklogFn, getDeletedIssueWorklogIds as getDeletedIssueWorklogIdsFn, getIssueWorklogsForIds as getIssueWorklogsForIdsFn, getUpdatedIssueWorklogIds as getUpdatedIssueWorklogIdsFn } from '../../raw-api/issue/worklog';
/**
 * Returns all work logs for an issue. Work logs won't be returned if the Log work field is hidden for the project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getIssueWorklog
 * @param options Request options.
 */
export function getIssueWorklogs(options) {
    return executeRequest(() => getIssueWorklogsFn(options), options.errorStrategy);
}
/**
 * Adds a new worklog entry to an issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-addWorklog
 * @param options Request options.
 */
export function addIssueWorklog(options) {
    return executeRequest(() => addIssueWorklogFn(options), options.errorStrategy);
}
/**
 * Returns a specific worklog. The work log won't be returned if the Log work field is hidden for the project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getWorklog
 * @param options Request options.
 */
export function getIssueWorklog(options) {
    return executeRequest(() => getIssueWorklogFn(options), options.errorStrategy);
}
/**
 * Updates an existing worklog entry. Fields possible for editing are: comment, visibility, started, timeSpent and timeSpentSeconds. Either timeSpent or timeSpentSeconds can be set. Fields which are not set will not be updated. For a request to be valid, it has to have at least one field change.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-updateWorklog
 * @param options Request options.
 */
export function updateIssueWorklog(options) {
    return executeRequest(() => updateIssueWorklogFn(options), options.errorStrategy);
}
/**
 * Deletes an existing worklog entry.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteWorklog
 * @param options Request options.
 */
export function deleteIssueWorklog(options) {
    return executeRequest(() => deleteIssueWorklogFn(options), options.errorStrategy);
}
/**
 * Returns worklogs id and delete time of worklogs that was deleted since given time. The returns set of worklogs is limited to 1000 elements. This API will not return worklogs deleted during last minute.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/worklog-getIdsOfWorklogsDeletedSince
 * @param options Request options.
 */
export function getDeletedIssueWorklogIds(options) {
    return executeRequest(() => getDeletedIssueWorklogIdsFn(options), options.errorStrategy);
}
/**
 * Returns worklogs for given worklog ids. Only worklogs to which the calling user has permissions, will be included in the result. The returns set of worklogs is limited to 1000 elements.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/worklog-getWorklogsForIds
 * @param options Request options.
 */
export function getIssueWorklogsForIds(options) {
    return executeRequest(() => getIssueWorklogsForIdsFn(options), options.errorStrategy);
}
/**
 * Returns worklogs id and update time of worklogs that was updated since given time. The returns set of worklogs is limited to 1000 elements. This API will not return worklogs updated during last minute.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/worklog-getIdsOfWorklogsModifiedSince
 * @param options Request options.
 */
export function getUpdatedIssueWorklogIds(options) {
    return executeRequest(() => getUpdatedIssueWorklogIdsFn(options), options.errorStrategy);
}
