import { executeRequest } from './common';
import { getPermissions as getPermissionsFn, getMyPermissions as getMyPermissionsFn } from '../raw-api/permission';
/**
 * Returns all permissions that are present in the JIRA instance - Global, Project and the global ones added by plugins
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/-getAllPermissions
 * @param options Request options.
 */
export function getPermissions(options) {
    return executeRequest(() => getPermissionsFn(options), options.errorStrategy);
}
/**
 * Returns all permissions in the system and whether the currently logged in user has them.
 * You can optionally provide a specific context to get permissions for (projectKey OR projectId OR issueKey OR issueId)
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/-getPermissions
 * @param options Request options.
 */
export function getMyPermissions(options) {
    return executeRequest(() => getMyPermissionsFn(options), options.errorStrategy);
}
