import { executeRequest } from '../common';
import { createProjectComponent as createProjectComponentFn, getProjectComponent as getProjectComponentFn, updateProjectComponent as updateProjectComponentFn, deleteProjectComponent as deleteProjectComponentFn, getProjectComponentRelatedIssues as getProjectComponentRelatedIssuesFn } from '../../raw-api/project/component';
/**
 * Create a component via POST.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/component-createComponent
 * @param options Request options.
 */
export function createProjectComponent(options) {
    return executeRequest(() => createProjectComponentFn(options), options.errorStrategy);
}
/**
 * Returns a project component.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/component-getComponent
 * @param options Request options.
 */
export function getProjectComponent(options) {
    return executeRequest(() => getProjectComponentFn(options), options.errorStrategy);
}
/**
 * Modify a component via PUT. If leadUserName is an empty string ("") the component lead will be removed.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/component-updateComponent
 * @param options Request options.
 */
export function updateProjectComponent(options) {
    return executeRequest(() => updateProjectComponentFn(options), options.errorStrategy);
}
/**
 * Delete a project component.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/component-delete
 * @param options Request options.
 */
export function deleteProjectComponent(options) {
    return executeRequest(() => deleteProjectComponentFn(options), options.errorStrategy);
}
/**
 * Returns counts of issues related to this component.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/component-getComponentRelatedIssues
 * @param options Request options.
 */
export function getProjectComponentRelatedIssues(options) {
    return executeRequest(() => getProjectComponentRelatedIssuesFn(options), options.errorStrategy);
}
