import { executeRequest } from '../common';
import { getProjectRoles as getProjectRolesFn, getProjectRole as getProjectRoleFn } from '../../raw-api/project/role';
/**
 * Returns all roles in the given project Id or key, with links to full details on each role.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/{projectIdOrKey}/role-getProjectRoles
 * @param options Request options.
 */
export function getProjectRoles(options) {
    return executeRequest(() => getProjectRolesFn(options), options.errorStrategy);
}
/**
 * Returns the details for a given project role in a project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/{projectIdOrKey}/role-getProjectRole
 * @param options Request options.
 */
export function getProjectRole(options) {
    return executeRequest(() => getProjectRoleFn(options), options.errorStrategy);
}
