import { executeRequest } from '../../common';
import { setProjectRoleActors as setProjectRoleActorsFn, addProjectRoleActorUsers as addProjectRoleActorUsersFn, deleteProjectRoleActor as deleteProjectRoleActorFn } from '../../../raw-api/project/role/actor';
/**
 * Updates a project role to include the specified actors (users or groups).
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/{projectIdOrKey}/role-setActors
 * @param options Request options.
 */
export function setProjectRoleActors(options) {
    return executeRequest(() => setProjectRoleActorsFn(options), options.errorStrategy);
}
/**
 * Adds an actor (user or group) to a project role.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/{projectIdOrKey}/role-addActorUsers
 * @param options Request options.
 */
export function addProjectRoleActorUsers(options) {
    return executeRequest(() => addProjectRoleActorUsersFn(options), options.errorStrategy);
}
/**
 * Deletes actors (users or groups) from a project role.
 * Delete a user from the role: /rest/api/2/project/{projectIdOrKey}/role/{roleId}?user={username}
 * Delete a group from the role: /rest/api/2/project/{projectIdOrKey}/role/{roleId}?group={groupname}
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/{projectIdOrKey}/role-deleteActor
 * @param options Request options.
 */
export function deleteProjectRoleActor(options) {
    return executeRequest(() => deleteProjectRoleActorFn(options), options.errorStrategy);
}
