import { Project } from '../../types/project';
/**
 * Returns all the project types defined on the JIRA instance, not taking into account whether the license to use those project types is valid or not.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/type-getAllProjectTypes
 * @param options Request options.
 */
export declare function getProjectTypes<T = Project.Type.GetTypes.Response.OK>(options: Project.Type.GetTypes.Options.HandledApi): Promise<Project.Type.GetTypes.Response.OK>;
/**
 * Returns the project type with the given key.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/type-getProjectTypeByKey
 * @param options Request options.
 */
export declare function getProjectType<T = Project.Type.GetType.Response.OK>(options: Project.Type.GetType.Options.HandledApi): Promise<import("../../definitions/project_type").ProjectType>;
/**
 * Returns the project type with the given key, if it is accessible to the logged in user. This takes into account whether the user is licensed on the Application that defines the project type.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/type-getAccessibleProjectTypeByKey
 * @param options Request options.
 */
export declare function getAccessibleProjectType<T = Project.Type.GetAccessibleType.Response.OK>(options: Project.Type.GetAccessibleType.Options.HandledApi): Promise<import("../../definitions/project_type").ProjectType>;
//# sourceMappingURL=type.d.ts.map