import { executeRequest } from '../common';
import { getProjectTypes as getProjectTypesFn, getProjectType as getProjectTypeFn, getAccessibleProjectType as getAccessibleProjectTypeFn } from '../../raw-api/project/type';
/**
 * Returns all the project types defined on the JIRA instance, not taking into account whether the license to use those project types is valid or not.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/type-getAllProjectTypes
 * @param options Request options.
 */
export function getProjectTypes(options) {
    return executeRequest(() => getProjectTypesFn(options), options.errorStrategy);
}
/**
 * Returns the project type with the given key.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/type-getProjectTypeByKey
 * @param options Request options.
 */
export function getProjectType(options) {
    return executeRequest(() => getProjectTypeFn(options), options.errorStrategy);
}
/**
 * Returns the project type with the given key, if it is accessible to the logged in user. This takes into account whether the user is licensed on the Application that defines the project type.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/type-getAccessibleProjectTypeByKey
 * @param options Request options.
 */
export function getAccessibleProjectType(options) {
    return executeRequest(() => getAccessibleProjectTypeFn(options), options.errorStrategy);
}
