import { executeRequest } from '../common';
import { createProjectVersion as createProjectVersionFn, moveProjectVersion as moveProjectVersionFn, getProjectVersion as getProjectVersionFn, updateProjectVersion as updateProjectVersionFn, deleteProjectVersion as deleteProjectVersionFn, mergeProjectVersion as mergeProjectVersionFn, removeAndReplaceProjectVersion as removeAndReplaceProjectVersionFn } from '../../raw-api/project/version';
/**
 * Create a version via POST.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-createVersion
 * @param options Request options.
 */
export function createProjectVersion(options) {
    return executeRequest(() => createProjectVersionFn(options), options.errorStrategy);
}
/**
 * Modify a version's sequence within a project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-moveVersion
 * @param options Request options.
 */
export function moveProjectVersion(options) {
    return executeRequest(() => moveProjectVersionFn(options), options.errorStrategy);
}
/**
 * Returns a project version.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-getVersion
 * @param options Request options.
 */
export function getProjectVersion(options) {
    return executeRequest(() => getProjectVersionFn(options), options.errorStrategy);
}
/**
 * Modify a version via PUT. Any fields present in the PUT will override existing values. As a convenience, if a field is not present, it is silently ignored.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-updateVersion
 * @param options Request options.
 */
export function updateProjectVersion(options) {
    return executeRequest(() => updateProjectVersionFn(options), options.errorStrategy);
}
/**
 * Delete a project version.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-delete
 * @param options Request options.
 */
export function deleteProjectVersion(options) {
    return executeRequest(() => deleteProjectVersionFn(options), options.errorStrategy);
}
/**
 * Merge versions.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-merge
 * @param options Request options.
 */
export function mergeProjectVersion(options) {
    return executeRequest(() => mergeProjectVersionFn(options), options.errorStrategy);
}
/**
 * Delete a project version.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-delete
 * @param options Request options.
 */
export function removeAndReplaceProjectVersion(options) {
    return executeRequest(() => removeAndReplaceProjectVersionFn(options), options.errorStrategy);
}
