import { executeRequest } from '../../common';
import { getProjectVersionRelatedIssueCount as getProjectVersionRelatedIssueCountFn, getProjectVersionUnresolvedIssueCount as getProjectVersionUnresolvedIssueCountFn } from '../../../raw-api/project/version/count';
/**
 * Returns a bean containing the number of fixed in and affected issues for the given version.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-getVersionRelatedIssues
 * @param options Request options.
 */
export function getProjectVersionRelatedIssueCount(options) {
    return executeRequest(() => getProjectVersionRelatedIssueCountFn(options), options.errorStrategy);
}
/**
 * Returns the number of unresolved issues for the given version
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-getVersionUnresolvedIssues
 * @param options Request options.
 */
export function getProjectVersionUnresolvedIssueCount(options) {
    return executeRequest(() => getProjectVersionUnresolvedIssueCountFn(options), options.errorStrategy);
}
