import { executeRequest } from '../common';
import { getGlobalProjectRoles as getGlobalProjectRolesFn, getGlobalProjectRole as getGlobalProjectRoleFn } from '../../raw-api/role/project';
/**
 * Get all the ProjectRoles available in JIRA. Currently this list is global.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/role-getProjectRoles
 * @param options Request options.
 */
export function getGlobalProjectRoles(options) {
    return executeRequest(() => getGlobalProjectRolesFn(options), options.errorStrategy);
}
/**
 * Get a specific ProjectRole available in JIRA.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/role-getProjectRolesById
 * @param options Request options.
 */
export function getGlobalProjectRole(options) {
    return executeRequest(() => getGlobalProjectRoleFn(options), options.errorStrategy);
}
