import { User } from '../types/user';
/**
 * Returns a user.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-getUser
 * @param options Request options.
 */
export declare function getUser<T = User.GetUser.Response.OK>(options: User.GetUser.Options.HandledApi): Promise<import("../definitions/user").UserFull>;
/**
 * Modify user. The "value" fields present will override the existing value. Fields skipped in request will not be changed.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-updateUser
 * @param options Request options.
 */
export declare function updateUser<T = User.UpdateUser.Response.OK>(options: User.UpdateUser.Options.HandledApi): Promise<import("../definitions/user").UserFull>;
/**
 * Create user. By default created user will not be notified with email. If password field is not set then password will be randomly generated.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-createUser
 * @param options Request options.
 */
export declare function createUser<T = User.CreateUser.Response.OK>(options: User.CreateUser.Options.HandledApi): Promise<import("../definitions/user").UserFull>;
/**
 * Removes user and its references (like project roles associations, watches, history).
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-removeUser
 * @param options Request options.
 */
export declare function removeUser<T = User.RemoveUser.Response.OK>(options: User.RemoveUser.Options.HandledApi): Promise<undefined>;
/**
 * Add user to given application. Admin permission will be required to perform this operation.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-addUserToApplication
 * @param options Request options.
 */
export declare function addUserToApplication<T = User.AddUserToApplication.Response.OK>(options: User.AddUserToApplication.Options.HandledApi): Promise<undefined>;
/**
 * Remove user from given application. Admin permission will be required to perform this operation.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-removeUserFromApplication
 * @param options Request options.
 */
export declare function removeUserFromApplication<T = User.RemoveUserFromApplication.Response.OK>(options: User.RemoveUserFromApplication.Options.HandledApi): Promise<undefined>;
/**
 * Modify user password.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-changeUserPassword
 * @param options Request options.
 */
export declare function changeUserPassword<T = User.ChangeUserPassword.Response.OK>(options: User.ChangeUserPassword.Options.HandledApi): Promise<undefined>;
//# sourceMappingURL=user.d.ts.map