import { executeRequest } from './common';
import { getUser as getUserFn, updateUser as updateUserFn, createUser as createUserFn, removeUser as removeUserFn, addUserToApplication as addUserToApplicationFn, removeUserFromApplication as removeUserFromApplicationFn, changeUserPassword as changeUserPasswordFn } from '../raw-api/user';
/**
 * Returns a user.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-getUser
 * @param options Request options.
 */
export function getUser(options) {
    return executeRequest(() => getUserFn(options), options.errorStrategy);
}
/**
 * Modify user. The "value" fields present will override the existing value. Fields skipped in request will not be changed.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-updateUser
 * @param options Request options.
 */
export function updateUser(options) {
    return executeRequest(() => updateUserFn(options), options.errorStrategy);
}
/**
 * Create user. By default created user will not be notified with email. If password field is not set then password will be randomly generated.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-createUser
 * @param options Request options.
 */
export function createUser(options) {
    return executeRequest(() => createUserFn(options), options.errorStrategy);
}
/**
 * Removes user and its references (like project roles associations, watches, history).
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-removeUser
 * @param options Request options.
 */
export function removeUser(options) {
    return executeRequest(() => removeUserFn(options), options.errorStrategy);
}
/**
 * Add user to given application. Admin permission will be required to perform this operation.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-addUserToApplication
 * @param options Request options.
 */
export function addUserToApplication(options) {
    return executeRequest(() => addUserToApplicationFn(options), options.errorStrategy);
}
/**
 * Remove user from given application. Admin permission will be required to perform this operation.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-removeUserFromApplication
 * @param options Request options.
 */
export function removeUserFromApplication(options) {
    return executeRequest(() => removeUserFromApplicationFn(options), options.errorStrategy);
}
/**
 * Modify user password.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-changeUserPassword
 * @param options Request options.
 */
export function changeUserPassword(options) {
    return executeRequest(() => changeUserPasswordFn(options), options.errorStrategy);
}
