import { executeRequest } from '../common';
import { getWorkflowStatuses as getWorkflowStatusesFn, getWorkflowStatus as getWorkflowStatusFn } from '../../raw-api/workflow/status';
/**
 * Returns a list of all statuses.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/status-getStatuses
 * @param options Request options.
 */
export function getWorkflowStatuses(options) {
    return executeRequest(() => getWorkflowStatusesFn(options), options.errorStrategy);
}
/**
 * Returns a full representation of the Status having the given id or name.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/status-getStatus
 * @param options Request options.
 */
export function getWorkflowStatus(options) {
    return executeRequest(() => getWorkflowStatusFn(options), options.errorStrategy);
}
