import { executeRequest } from '../../common';
import { getWorkflowStatusCategories as getWorkflowStatusCategoriesFn, getWorkflowStatusCategory as getWorkflowStatusCategoryFn } from '../../../raw-api/workflow/status/category';
/**
 * Returns a list of all status categories.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/statuscategory-getStatusCategories
 * @param options Request options.
 */
export function getWorkflowStatusCategories(options) {
    return executeRequest(() => getWorkflowStatusCategoriesFn(options), options.errorStrategy);
}
/**
 * Returns a full representation of the StatusCategory having the given id or key.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/statuscategory-getStatusCategory
 * @param options Request options.
 */
export function getWorkflowStatusCategory(options) {
    return executeRequest(() => getWorkflowStatusCategoryFn(options), options.errorStrategy);
}
