import { constructUrl } from '@avst-api/commons';
import { httpGet } from './common';
/**
 * Returns a list of all dashboards, optionally filtering them.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/dashboard-list
 * @param options Request options.
 */
export function getAllDashboards(options) {
    const { connectionId: instanceId, headers, filter, startAt, maxResults } = options;
    const queryParams = { filter, startAt, maxResults };
    return httpGet(instanceId, constructUrl('/rest/api/2/dashboard', queryParams), headers);
}
/**
 * Returns a single dashboard.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/dashboard-getDashboard
 * @param options Request options.
 */
export function getDashboardById(options) {
    const { connectionId: instanceId, headers, id } = options;
    return httpGet(instanceId, `/rest/api/2/dashboard/${id}`, headers);
}
