import { httpDelete, httpGet, httpPost, httpPut } from './common';
import { constructUrl } from '@avst-api/commons';
/**
 * Returns a filter given an id.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getFilter
 * @param options Request options.
 */
export function getFilter(options) {
    const { connectionId: instanceId, id, headers, expand } = options;
    const queryParams = { expand };
    return httpGet(instanceId, constructUrl(`/rest/api/2/filter/${id}`, queryParams), headers);
}
/**
 * Returns the favourite filters of the logged-in user.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getFavouriteFilters
 * @param options Request options.
 */
export function getMyFavouriteFilters(options) {
    const { connectionId: instanceId, headers, expand } = options;
    const queryParams = { expand };
    return httpGet(instanceId, constructUrl('/rest/api/2/filter/favourite', queryParams), headers);
}
/**
 * Creates a new filter, and returns newly created filter. Currently sets permissions just using the users default sharing permissions.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-createFilter
 * @param options Request options.
 */
export function createFilter(options) {
    const { connectionId: instanceId, body, headers, expand } = options;
    const queryParams = { expand };
    return httpPost(instanceId, constructUrl('/rest/api/2/filter', queryParams), body, headers);
}
/**
 * Updates an existing filter, and returns its new value.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-editFilter
 * @param options Request options.
 */
export function editFilter(options) {
    const { connectionId: instanceId, body, headers, id, expand } = options;
    const queryParams = { expand };
    return httpPut(instanceId, constructUrl(`/rest/api/2/filter/${id}`, queryParams), body, headers);
}
/**
 * Delete a filter.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-deleteFilter
 * @param options Request options.
 */
export function deleteFilter(options) {
    const { connectionId: instanceId, headers, id } = options;
    return httpDelete(instanceId, `/rest/api/2/filter/${id}`, headers, true);
}
