import { httpDelete, httpGet, httpPut } from '../common';
/**
 * Returns the default columns for the given filter. Currently logged in user will be used as the user making such request.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-defaultColumns
 * @param options Request options.
 */
export function getFilterDefaultColumns(options) {
    const { connectionId: instanceId, headers, id } = options;
    return httpGet(instanceId, `/rest/api/2/filter/${id}/columns`, headers);
}
/**
 * Sets the default columns for the given filter.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-setColumns
 * @param options Request options.
 */
export function setFilterDefaultColumns(options) {
    const { connectionId: instanceId, headers, id, body } = options;
    return httpPut(instanceId, `/rest/api/2/filter/${id}/columns`, body, headers, true);
}
/**
 * Resets the columns for the given filter such that the filter no longer has its own column config.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-resetColumns
 * @param options Request options.
 */
export function resetFilterColumns(options) {
    const { connectionId: instanceId, headers, id } = options;
    return httpDelete(instanceId, `/rest/api/2/filter/${id}/columns`, headers, true);
}
