import { httpGet, httpPut } from '../common';
/**
 * Returns the default share scope of the logged-in user.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getDefaultShareScope
 * @param options Request options.
 */
export function getDefaultShareScope(options) {
    const { connectionId: instanceId, headers } = options;
    return httpGet(instanceId, '/rest/api/2/filter/defaultShareScope', headers);
}
/**
 * Sets the default share scope of the logged-in user. Available values are GLOBAL and PRIVATE.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-setDefaultShareScope
 * @param options Request options.
 */
export function setDefaultShareScope(options) {
    const { connectionId: instanceId, headers, body } = options;
    return httpPut(instanceId, '/rest/api/2/filter/defaultShareScope', body, headers);
}
