import { httpDelete, httpGet, httpPost } from '../../common';
/**
 * Returns all share permissions of the given filter.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getSharePermissions
 * @param options Request options.
 */
export function getFilterSharePermissions(options) {
    const { connectionId: instanceId, headers, id } = options;
    return httpGet(instanceId, `/rest/api/2/filter/${id}/permission`, headers);
}
/**
 * Adds a share permissions to the given filter. Adding a global permission removes all previous permissions from the filter.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-addSharePermission
 * @param options Request options.
 */
export function addFilterSharePermission(options) {
    const { connectionId: instanceId, headers, id, body } = options;
    return httpPost(instanceId, `/rest/api/2/filter/${id}/permission`, body, headers);
}
/**
 * Returns a single share permission of the given filter.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getSharePermission
 * @param options Request options.
 */
export function getFilterSharePermission(options) {
    const { connectionId: instanceId, headers, id, permissionId } = options;
    return httpGet(instanceId, `/rest/api/2/filter/${id}/permission/${permissionId}`, headers);
}
/**
 * Removes a share permissions from the given filter.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/filter-getSharePermission
 * @param options Request options.
 */
export function deleteFilterSharePermission(options) {
    const { connectionId: instanceId, headers, id, permissionId } = options;
    return httpDelete(instanceId, `/rest/api/2/filter/${id}/permission/${permissionId}`, headers, true);
}
