import { httpPost, httpDelete } from './common';
import { constructUrl } from '@avst-api/commons';
/**
 * Creates a group by given group parameter.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/group-createGroup
 * @param options Request options.
 */
export function createGroup(options) {
    const { connectionId: instanceId, body, headers } = options;
    return httpPost(instanceId, '/rest/api/2/group', body, headers);
}
/**
 * Deletes a group by given group parameter.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/group-removeGroup
 * @param options Request options.
 */
export function removeGroup(options) {
    const { connectionId: instanceId, headers, groupname, swapGroup } = options;
    const queryParams = { groupname, swapGroup };
    return httpDelete(instanceId, constructUrl('/rest/api/2/group', queryParams), headers, true);
}
