import { httpPost, httpGet, httpDelete } from '../common';
import { constructUrl } from '@avst-api/commons';
/**
 * This resource returns a paginated list of users who are members of the specified group and its subgroups. Users in the page are ordered by user names. User of this resource is required to have sysadmin or admin permissions.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/group-getUsersFromGroup
 * @param options Request options.
 */
export function getUsersFromGroup(options) {
    const { connectionId: instanceId, headers, groupname, includeInactiveUsers, maxResults, startAt } = options;
    const queryParams = { groupname, includeInactiveUsers, maxResults, startAt };
    return httpGet(instanceId, constructUrl('/rest/api/2/group/member', queryParams), headers);
}
/**
 * Adds given user to a group.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/group-addUserToGroup
 * @param options Request options.
 */
export function addUsersToGroup(options) {
    const { connectionId: instanceId, body, headers, groupname } = options;
    const queryParams = { groupname };
    return httpPost(instanceId, constructUrl('/rest/api/2/group/user', queryParams), body, headers);
}
/**
 * Removes given user from a group.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/group-removeUserFromGroup
 * @param options Request options.
 */
export function removeUsersFromGroup(options) {
    const { connectionId: instanceId, headers, groupname, username } = options;
    const queryParams = { groupname, username };
    return httpDelete(instanceId, constructUrl('/rest/api/2/group/user', queryParams), headers, true);
}
