import { Instance } from '../types/instance';
/**
 * Returns the information if the optional features in JIRA are enabled or disabled. If the time tracking is enabled, it also returns the detailed information about time tracking configuration.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/configuration-getConfiguration
 * @param options Request options.
 */
export declare function getInstanceConfiguration(options: Instance.GetConfiguration.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../definitions/instance").GetConfigurationResponse | undefined>>;
/**
 * Returns an application property.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/application-properties-getProperty
 * @param options Request options.
 */
export declare function getApplicationProperty(options: Instance.GetApplicationProperty.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../definitions/property").Property | undefined>>;
/**
 * Modify an application property via PUT. The "value" field present in the PUT will override the existing value.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/application-properties-setPropertyViaRestfulTable
 * @param options Request options.
 */
export declare function setApplicationProperty(options: Instance.SetApplicationProperty.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../definitions/property").Property | undefined>>;
/**
 * Returns the properties that are displayed on the "General Configuration > Advanced Settings" page.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/application-properties-getAdvancedSettings
 * @param options Request options.
 */
export declare function getAdvancedSettings(options: Instance.GetAdvancedSettings.Options.RawApi): Promise<import("@avst-api/commons").Response<Instance.GetAdvancedSettings.Response.OK | undefined>>;
/**
 * Returns general information about the current JIRA server.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/serverInfo-getServerInfo
 * @param options Request options.
 */
export declare function getInstanceInfo(options: Instance.GetInfo.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../definitions/instance").GetInfoResponse | undefined>>;
//# sourceMappingURL=instance.d.ts.map