import { Issue } from '../types/issue';
/**
 * Creates an issue or a sub-task from a JSON representation.
 * The fields that can be set on create, in either the fields parameter or the update parameter can be determined using the /rest/api/2/issue/createmeta resource. If a field is not configured to appear on the create screen, then it will not be in the createmeta, and a field validation error will occur if it is submitted.
 * Creating a sub-task is similar to creating a regular issue, with two important differences:
 * the issueType field must correspond to a sub-task issue type (you can use /issue/createmeta to discover sub-task issue types), and you must provide a parent field in the issue create request containing the id or key of the parent issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-createIssue
 * @param options Request options.
 */
export declare function createIssue(options: Issue.CreateIssue.Options.RawApi): Promise<import("@avst-api/commons").Response<Issue.CreateIssue.Response.OK | undefined>>;
/**
 * Delete an issue. If the issue has subtasks you must set the parameter deleteSubtasks=true to delete the issue. You cannot delete an issue without its subtasks also being deleted.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteIssue
 * @param options Request options.
 */
export declare function deleteIssue(options: Issue.DeleteIssue.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
/**
 * Returns a full representation of the issue for the given issue key.
 * JIRA will attempt to identify the issue by the issueIdOrKey path parameter. This can be an issue id, or an issue key. If the issue cannot be found via an exact match, JIRA will also look for the issue in a case-insensitive way, or by looking to see if the issue was moved. In either of these cases, the request will proceed as normal (a 302 or other redirect will not be returned). The issue key contained in the response will indicate the current value of issue's key.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getIssue
 * @param options Request options.
 */
export declare function getIssue(options: Issue.GetIssue.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../definitions/issue").IssueResponse | undefined>>;
/**
 * Edits an issue from a JSON representation.
 * The issue can either be updated by setting explicit the field value(s) or by using an operation to change the field value.
 * The fields that can be updated, in either the fields parameter or the update parameter, can be determined using the /rest/api/2/issue/{issueIdOrKey}/editmeta resource.
 * If a field is not configured to appear on the edit screen, then it will not be in the editmeta, and a field validation error will occur if it is submitted.
 * Specifying a "field_id": field_value in the "fields" is a shorthand for a "set" operation in the "update" section.
 * Field should appear either in "fields" or "update", not in both.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-editIssue
 * @param options Request options.
 */
export declare function editIssue(options: Issue.EditIssue.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
/**
 * Assigns an issue to a user. You can use this resource to assign issues when the user submitting the request has the assign permission but not the edit issue permission. If the name is "-1" automatic assignee is used. A null name will remove the assignee.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-assign
 * @param options Request options.
 */
export declare function assignIssue(options: Issue.AssignIssue.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
/**
 * Sends a notification (email) to the list or recipients defined in the request.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-notify
 * @param options Request options.
 */
export declare function sendNotificationForIssue(options: Issue.SendNotification.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
//# sourceMappingURL=issue.d.ts.map