import { httpDelete, httpGet, httpPost } from '../common';
import { getBodyForFileUpload } from '@avst-api/commons';
/**
 * Returns the meta-data for an attachment, including the URI of the actual attached file.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/attachment-getAttachment
 * @param options Request options.
 */
export function getIssueAttachment(options) {
    const { connectionId: instanceId, id, headers } = options;
    return httpGet(instanceId, `/rest/api/2/attachment/${id}`, headers);
}
/**
 * Remove an attachment from an issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/attachment-removeAttachment
 * @param options Request options.
 */
export function removeIssueAttachment(options) {
    const { connectionId: instanceId, id, headers } = options;
    return httpDelete(instanceId, `/rest/api/2/attachment/${id}`, headers, true);
}
/**
 * Add one or more attachments to an issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue/{issueIdOrKey}/attachments-addAttachment
 * @param options Request options.
 */
export function addIssueAttachment(options) {
    const { connectionId: instanceId, issueIdOrKey, body, headers } = options;
    return httpPost(instanceId, `/rest/api/2/issue/${issueIdOrKey}/attachments`, getBodyForFileUpload(body), headers);
}
