import { Issue } from '../../../types/issue';
/**
 * A REST sub-resource representing the remote issue links on the issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getRemoteIssueLinks
 * @param options Request options.
 */
export declare function getRemoteIssueLinks(options: Issue.Link.Remote.GetLinks.Options.RawApi): Promise<import("@avst-api/commons").Response<Issue.Link.Remote.GetLinks.Response.OK | undefined>>;
/**
 * Creates or updates a remote issue link from a JSON representation. If a globalId is provided and a remote issue link exists with that globalId, the remote issue link is updated. Otherwise, the remote issue link is created.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-createOrUpdateRemoteIssueLink
 * @param options Request options.
 */
export declare function createOrUpdateRemoteIssueLink(options: Issue.Link.Remote.CreateOrUpdateLink.Options.RawApi): Promise<import("@avst-api/commons").Response<Issue.Link.Remote.CreateOrUpdateLink.Response.OK | undefined>>;
/**
 * Delete the remote issue link with the given global id on the issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteRemoteIssueLinkByGlobalId
 * @param options Request options.
 */
export declare function deleteRemoteIssueLinkByGlobalId(options: Issue.Link.Remote.DeleteLinkByGlobalId.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
/**
 * Get the remote issue link with the given id on the issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getRemoteIssueLinkById
 * @param options Request options.
 */
export declare function getRemoteIssueLink(options: Issue.Link.Remote.GetLink.Options.RawApi): Promise<import("@avst-api/commons").Response<Issue.Link.Remote.GetLink.Response.OK | undefined>>;
/**
 * Updates a remote issue link from a JSON representation. Any fields not provided are set to null.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-updateRemoteIssueLink
 * @param options Request options.
 */
export declare function updateRemoteIssueLink(options: Issue.Link.Remote.UpdateLink.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
/**
 * Delete the remote issue link with the given id on the issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-deleteRemoteIssueLinkById
 * @param options Request options.
 */
export declare function deleteRemoteIssueLink(options: Issue.Link.Remote.DeleteLink.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
//# sourceMappingURL=remote.d.ts.map