import { Issue } from '../../../types/issue';
/**
 * Returns a list of available issue link types, if issue linking is enabled. Each issue link type has an id, a name and a label for the outward and inward link relationship.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-getIssueLinkTypes
 * @param options Request options.
 */
export declare function getIssueLinkTypes(options: Issue.Link.Type.GetTypes.Options.RawApi): Promise<import("@avst-api/commons").Response<Issue.Link.Type.GetTypes.Response.OK | undefined>>;
/**
 * Returns for a given issue link type id all information about this issue link type.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-getIssueLinkType
 * @param options Request options.
 */
export declare function getIssueLinkType(options: Issue.Link.Type.GetType.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/issue_link_type").IssueLinkType | undefined>>;
/**
 * Create a new issue link type.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-createIssueLinkType
 * @param options Request options.
 */
export declare function createIssueLinkType(options: Issue.Link.Type.CreateType.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/issue_link_type").IssueLinkType | undefined>>;
/**
 * Delete the specified issue link type.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-deleteIssueLinkType
 * @param options Request options.
 */
export declare function deleteIssueLinkType(options: Issue.Link.Type.DeleteType.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
/**
 * Update the specified issue link type.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issueLinkType-updateIssueLinkType
 * @param options Request options.
 */
export declare function updateIssueLinkType(options: Issue.Link.Type.UpdateType.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../../definitions/issue_link_type").IssueLinkType | undefined>>;
//# sourceMappingURL=type.d.ts.map