import { httpGet } from '../common';
import { constructUrl } from '@avst-api/commons';
/**
 * Returns the meta data for editing an issue. The fields in the editmeta correspond to the fields in the edit screen for the issue. Fields not in the screen will not be in the editmeta.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getEditIssueMeta
 * @param options Request options.
 */
export function getEditIssueMetadata(options) {
    const { connectionId: instanceId, issueIdOrKey, headers } = options;
    return httpGet(instanceId, `/rest/api/2/issue/${issueIdOrKey}/editmeta`, headers);
}
/**
 * Returns the meta data for creating issues. This includes the available projects, issue types and fields, including field types and whether or not those fields are required. Projects will not be returned if the user does not have permission to create issues in that project.
 * The fields in the createmeta correspond to the fields in the create screen for the project/issuetype. Fields not in the screen will not be in the createmeta.
 * Fields will only be returned if expand=projects.issuetypes.fields.
 * The results can be filtered by project and/or issue type, given by the query params.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getCreateIssueMeta
 * @param options Request options.
 */
export function getCreateIssueMetadata(options) {
    const { connectionId: instanceId, headers, issuetypeIds, issuetypeNames, projectIds, projectKeys } = options;
    const queryParams = { issuetypeIds, issuetypeNames, projectIds, projectKeys };
    return httpGet(instanceId, constructUrl('/rest/api/2/issue/createmeta', queryParams), headers);
}
