import { httpPost, httpGet } from '../common';
/**
 * Returns an issue's subtask list.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue/{issueIdOrKey}/subtask-getSubTasks
 * @param options Request options.
 */
export function getIssueSubTasks(options) {
    const { connectionId: instanceId, issueIdOrKey, headers } = options;
    return httpGet(instanceId, `/rest/api/2/issue/${issueIdOrKey}/subtask`, headers);
}
/**
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue/{issueIdOrKey}/subtask-canMoveSubTask
 * @param options Request options.
 */
export function canMoveIssueSubTask(options) {
    const { connectionId: instanceId, issueIdOrKey, headers } = options;
    return httpGet(instanceId, `/rest/api/2/issue/${issueIdOrKey}/subtask/move`, headers);
}
/**
 * Reorders an issue's subtasks by moving the subtask at index "from" to index "to".
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue/{issueIdOrKey}/subtask-moveSubTasks
 * @param options Request options.
 */
export function moveIssueSubTasks(options) {
    const { connectionId: instanceId, issueIdOrKey, body, headers } = options;
    return httpPost(instanceId, `/rest/api/2/issue/${issueIdOrKey}/subtask/move`, body, headers, true);
}
