import { Issue } from '../../types/issue';
/**
 * Returns a list of all issue types visible to the user.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-getIssueAllTypes
 * @param options Request options.
 */
export declare function getIssueTypes(options: Issue.Type.GetTypes.Options.RawApi): Promise<import("@avst-api/commons").Response<Issue.Type.GetTypes.Response.OK | undefined>>;
/**
 * Returns a full representation of the issue type that has the given id.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-getIssueType
 * @param options Request options.
 */
export declare function getIssueType(options: Issue.Type.GetType.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/issue_type").IssueType | undefined>>;
/**
 * Creates an issue type from a JSON representation and adds the issue newly created issue type to the default issue type scheme.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-createIssueType
 * @param options Request options.
 */
export declare function createIssueType(options: Issue.Type.CreateType.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/issue_type").IssueType | undefined>>;
/**
 * Deletes the specified issue type. If the issue type has any associated issues, these issues will be migrated to the alternative issue type specified in the parameter.
 * You can determine the alternative issue types by calling the /rest/api/2/issuetype/{id}/alternatives resource.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-deleteIssueType
 * @param options Request options.
 */
export declare function deleteIssueType(options: Issue.Type.DeleteType.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
/**
 * Updates the specified issue type from a JSON representation.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-updateIssueType
 * @param options Request options.
 */
export declare function updateIssueType(options: Issue.Type.UpdateType.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../../definitions/issue_type").IssueType | undefined>>;
/**
 * Returns a list of all alternative issue types for the given issue type id. The list will contain these issues types, to which issues assigned to the given issue type can be migrated.
 * The suitable alternatives are issue types which are assigned to the same workflow, the same field configuration and the same screen scheme.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issuetype-getAlternativeIssueTypes
 * @param options Request options.
 */
export declare function getAlternativeIssueTypes(options: Issue.Type.GetAlternativeTypes.Options.RawApi): Promise<import("@avst-api/commons").Response<Issue.Type.GetAlternativeTypes.Response.OK | undefined>>;
//# sourceMappingURL=type.d.ts.map