import { httpPost, httpGet, httpDelete } from '../common';
/**
 * Remove your vote from an issue. (i.e. "unvote").
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-removeVote
 * @param options Request options.
 */
export function removeIssueVote(options) {
    const { connectionId: instanceId, issueIdOrKey, headers } = options;
    return httpDelete(instanceId, `/rest/api/2/issue/${issueIdOrKey}/votes`, headers, true);
}
/**
 * Cast your vote in favour of an issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-addVote
 * @param options Request options.
 */
export function addIssueVote(options) {
    const { connectionId: instanceId, issueIdOrKey, headers } = options;
    return httpPost(instanceId, `/rest/api/2/issue/${issueIdOrKey}/votes`, undefined, headers, true);
}
/**
 * A REST sub-resource representing the voters on the issue.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getVotes
 * @param options Request options.
 */
export function getIssueVotes(options) {
    const { connectionId: instanceId, issueIdOrKey, headers } = options;
    return httpGet(instanceId, `/rest/api/2/issue/${issueIdOrKey}/votes`, headers);
}
