import { httpPost, httpGet, httpDelete } from '../common';
import { constructUrl } from '@avst-api/commons';
/**
 * Returns the list of watchers for the issue with the given key.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-getIssueWatchers
 * @param options Request options.
 */
export function getIssueWatchers(options) {
    const { connectionId: instanceId, issueIdOrKey, headers } = options;
    return httpGet(instanceId, `/rest/api/2/issue/${issueIdOrKey}/watchers`, headers);
}
/**
 * Adds a user to an issue's watcher list.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-addWatcher
 * @param options Request options.
 */
export function addIssueWatcher(options) {
    const { connectionId: instanceId, issueIdOrKey, body, headers } = options;
    return httpPost(instanceId, `/rest/api/2/issue/${issueIdOrKey}/watchers`, body, headers, true);
}
/**
 * Removes a user from an issue's watcher list.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/issue-removeWatcher
 * @param options Request options.
 */
export function removeIssueWatcher(options) {
    const { connectionId: instanceId, issueIdOrKey, headers, username } = options;
    const queryParams = { username };
    return httpDelete(instanceId, constructUrl(`/rest/api/2/issue/${issueIdOrKey}/watchers`, queryParams), headers, true);
}
