import { constructUrl } from '@avst-api/commons';
import { httpGet } from './common';
/**
 * Returns all permissions that are present in the JIRA instance - Global, Project and the global ones added by plugins
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/-getAllPermissions
 * @param options Request options.
 */
export function getPermissions(options) {
    const { connectionId: instanceId, headers } = options;
    return httpGet(instanceId, '/rest/api/2/permissions', headers);
}
/**
 * Returns all permissions in the system and whether the currently logged in user has them.
 * You can optionally provide a specific context to get permissions for (projectKey OR projectId OR issueKey OR issueId)
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/-getPermissions
 * @param options Request options.
 */
export function getMyPermissions(options) {
    const { connectionId: instanceId, headers, projectKey, projectId, issueKey } = options;
    const queryParams = { projectKey, projectId, issueKey };
    return httpGet(instanceId, constructUrl('/rest/api/2/mypermissions', queryParams), headers);
}
