import { Project } from '../types/project';
/**
 * Returns all projects which are visible for the currently logged in user. If no user is logged in, it returns the list of projects that are visible when using anonymous access.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getAllProjects
 * @param options Request options.
 */
export declare function getProjects(options: Project.GetProjects.Options.RawApi): Promise<import("@avst-api/commons").Response<Project.GetProjects.Response.OK | undefined>>;
/**
 * Creates a new project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-createProject
 * @param options Request options.
 */
export declare function createProject(options: Project.CreateProject.Options.RawApi): Promise<import("@avst-api/commons").Response<Project.CreateProject.Response.OK | undefined>>;
/**
 * Contains a full representation of a project in JSON format.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getProject
 * @param options Request options.
 */
export declare function getProject(options: Project.GetProject.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../definitions/project").Project | undefined>>;
/**
 * Updates a project. Only non null values sent in JSON will be updated in the project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-updateProject
 * @param options Request options.
 */
export declare function updateProject(options: Project.UpdateProject.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../definitions/project").Project | undefined>>;
/**
 * Deletes a project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-deleteProject
 * @param options Request options.
 */
export declare function deleteProject(options: Project.DeleteProject.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
/**
 * Archives a project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-archiveProject
 * @param options Request options.
 */
export declare function archiveProject(options: Project.ArchiveProject.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
/**
 * Contains a full representation of a the specified project's components.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getProjectComponents
 * @param options Request options.
 */
export declare function getProjectComponents(options: Project.GetComponents.Options.RawApi): Promise<import("@avst-api/commons").Response<Project.GetComponents.Response.OK | undefined>>;
/**
 * Restore an archived project. In case of success restored project should be re-indexed.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-restoreProject
 * @param options Request options.
 */
export declare function restoreProject(options: Project.RestoreProject.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
/**
 * Get all issue types with valid status values for a project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getAllStatuses
 * @param options Request options.
 */
export declare function getProjectStatuses(options: Project.GetStatuses.Options.RawApi): Promise<import("@avst-api/commons").Response<Project.GetStatuses.Response.OK | undefined>>;
/**
 * Updates the type of a project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-updateProjectType
 * @param options Request options.
 */
export declare function updateProjectType(options: Project.UpdateProjectType.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../definitions/project").Project | undefined>>;
/**
 * Returns all versions for the specified project. Results are paginated.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getProjectVersionsPaginated
 * @param options Request options.
 */
export declare function getProjectVersionsPaginated(options: Project.GetVersionsPaginated.Options.RawApi): Promise<import("@avst-api/commons").Response<Project.GetVersionsPaginated.Response.OK | undefined>>;
/**
 * Contains a full representation of a the specified project's versions.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project-getProjectVersions
 * @param options Request options.
 */
export declare function getProjectVersions(options: Project.GetVersions.Options.RawApi): Promise<import("@avst-api/commons").Response<Project.GetVersions.Response.OK | undefined>>;
//# sourceMappingURL=project.d.ts.map