import { httpPost, httpGet, httpPut, httpDelete } from '../common';
import { constructUrl } from '@avst-api/commons';
/**
 * Create a component via POST.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/component-createComponent
 * @param options Request options.
 */
export function createProjectComponent(options) {
    const { connectionId: instanceId, body, headers } = options;
    return httpPost(instanceId, '/rest/api/2/component', body, headers);
}
/**
 * Returns a project component.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/component-getComponent
 * @param options Request options.
 */
export function getProjectComponent(options) {
    const { connectionId: instanceId, id, headers } = options;
    return httpGet(instanceId, `/rest/api/2/component/${id}`, headers);
}
/**
 * Modify a component via PUT. If leadUserName is an empty string ("") the component lead will be removed.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/component-updateComponent
 * @param options Request options.
 */
export function updateProjectComponent(options) {
    const { connectionId: instanceId, id, body, headers } = options;
    return httpPut(instanceId, `/rest/api/2/component/${id}`, body, headers);
}
/**
 * Delete a project component.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/component-delete
 * @param options Request options.
 */
export function deleteProjectComponent(options) {
    const { connectionId: instanceId, id, headers, moveIssuesTo } = options;
    const queryParams = { moveIssuesTo };
    return httpDelete(instanceId, constructUrl(`/rest/api/2/component/${id}`, queryParams), headers, true);
}
/**
 * Returns counts of issues related to this component.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/component-getComponentRelatedIssues
 * @param options Request options.
 */
export function getProjectComponentRelatedIssues(options) {
    const { connectionId: instanceId, id, headers } = options;
    return httpGet(instanceId, `/rest/api/2/component/${id}/relatedIssueCounts`, headers);
}
