import { httpGet } from '../common';
/**
 * Returns all roles in the given project Id or key, with links to full details on each role.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/{projectIdOrKey}/role-getProjectRoles
 * @param options Request options.
 */
export function getProjectRoles(options) {
    const { connectionId: instanceId, projectIdOrKey, headers } = options;
    return httpGet(instanceId, `/rest/api/2/project/${projectIdOrKey}/role`, headers);
}
/**
 * Returns the details for a given project role in a project.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/{projectIdOrKey}/role-getProjectRole
 * @param options Request options.
 */
export function getProjectRole(options) {
    const { connectionId: instanceId, projectIdOrKey, id, headers } = options;
    return httpGet(instanceId, `/rest/api/2/project/${projectIdOrKey}/role/${id}`, headers);
}
