import { httpDelete, httpPut, httpPost } from '../../common';
import { constructUrl } from '@avst-api/commons';
/**
 * Updates a project role to include the specified actors (users or groups).
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/{projectIdOrKey}/role-setActors
 * @param options Request options.
 */
export function setProjectRoleActors(options) {
    const { connectionId: instanceId, projectIdOrKey, id, body, headers } = options;
    return httpPut(instanceId, `/rest/api/2/project/${projectIdOrKey}/role/${id}`, body, headers);
}
/**
 * Adds an actor (user or group) to a project role.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/{projectIdOrKey}/role-addActorUsers
 * @param options Request options.
 */
export function addProjectRoleActorUsers(options) {
    const { connectionId: instanceId, projectIdOrKey, id, body, headers } = options;
    return httpPost(instanceId, `/rest/api/2/project/${projectIdOrKey}/role/${id}`, body, headers);
}
/**
 * Deletes actors (users or groups) from a project role.
 * Delete a user from the role: /rest/api/2/project/{projectIdOrKey}/role/{roleId}?user={username}
 * Delete a group from the role: /rest/api/2/project/{projectIdOrKey}/role/{roleId}?group={groupname}
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/{projectIdOrKey}/role-deleteActor
 * @param options Request options.
 */
export function deleteProjectRoleActor(options) {
    const { connectionId: instanceId, projectIdOrKey, id, headers, group, user } = options;
    const queryParams = { group, user };
    return httpDelete(instanceId, constructUrl(`/rest/api/2/project/${projectIdOrKey}/role/${id}`, queryParams), headers, true);
}
