import { httpGet } from '../common';
/**
 * Returns all the project types defined on the JIRA instance, not taking into account whether the license to use those project types is valid or not.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/type-getAllProjectTypes
 * @param options Request options.
 */
export function getProjectTypes(options) {
    const { connectionId: instanceId, headers } = options;
    return httpGet(instanceId, '/rest/api/2/project/type', headers);
}
/**
 * Returns the project type with the given key.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/type-getProjectTypeByKey
 * @param options Request options.
 */
export function getProjectType(options) {
    const { connectionId: instanceId, projectTypeKey, headers } = options;
    return httpGet(instanceId, `/rest/api/2/project/type/${projectTypeKey}`, headers);
}
/**
 * Returns the project type with the given key, if it is accessible to the logged in user. This takes into account whether the user is licensed on the Application that defines the project type.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/project/type-getAccessibleProjectTypeByKey
 * @param options Request options.
 */
export function getAccessibleProjectType(options) {
    const { connectionId: instanceId, projectTypeKey, headers } = options;
    return httpGet(instanceId, `/rest/api/2/project/type/${projectTypeKey}/accessible`, headers);
}
