import { httpGet } from '../../common';
/**
 * Returns a bean containing the number of fixed in and affected issues for the given version.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-getVersionRelatedIssues
 * @param options Request options.
 */
export function getProjectVersionRelatedIssueCount(options) {
    const { connectionId: instanceId, id, headers } = options;
    return httpGet(instanceId, `/rest/api/2/version/${id}/relatedIssueCounts`, headers);
}
/**
 * Returns the number of unresolved issues for the given version
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/version-getVersionUnresolvedIssues
 * @param options Request options.
 */
export function getProjectVersionUnresolvedIssueCount(options) {
    const { connectionId: instanceId, id, headers } = options;
    return httpGet(instanceId, `/rest/api/2/version/${id}/unresolvedIssueCount`, headers);
}
