import { User } from '../types/user';
/**
 * Returns a user.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-getUser
 * @param options Request options.
 */
export declare function getUser(options: User.GetUser.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../definitions/user").UserFull | undefined>>;
/**
 * Modify user. The "value" fields present will override the existing value. Fields skipped in request will not be changed.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-updateUser
 * @param options Request options.
 */
export declare function updateUser(options: User.UpdateUser.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../definitions/user").UserFull | undefined>>;
/**
 * Create user. By default created user will not be notified with email. If password field is not set then password will be randomly generated.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-createUser
 * @param options Request options.
 */
export declare function createUser(options: User.CreateUser.Options.RawApi): Promise<import("@avst-api/commons").Response<import("../definitions/user").UserFull | undefined>>;
/**
 * Removes user and its references (like project roles associations, watches, history).
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-removeUser
 * @param options Request options.
 */
export declare function removeUser(options: User.RemoveUser.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
/**
 * Add user to given application. Admin permission will be required to perform this operation.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-addUserToApplication
 * @param options Request options.
 */
export declare function addUserToApplication(options: User.AddUserToApplication.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
/**
 * Remove user from given application. Admin permission will be required to perform this operation.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-removeUserFromApplication
 * @param options Request options.
 */
export declare function removeUserFromApplication(options: User.RemoveUserFromApplication.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
/**
 * Modify user password.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-changeUserPassword
 * @param options Request options.
 */
export declare function changeUserPassword(options: User.ChangeUserPassword.Options.RawApi): Promise<import("@avst-api/commons").Response<undefined>>;
//# sourceMappingURL=user.d.ts.map