import { User } from '../../types/user';
/**
 * Returns a list of users that match the search string. This resource cannot be accessed anonymously. Please note that this resource should be called with an issue key when a list of assignable users is retrieved for editing. For create only a project key should be supplied. The list of assignable users may be incorrect if it's called with the project key for editing.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-findAssignableUsers
 * @param options Request options.
 */
export declare function findAssignableUsers(options: User.Search.FindAssignableUsers.Options.RawApi): Promise<import("@avst-api/commons").Response<User.Search.FindAssignableUsers.Response.OK | undefined>>;
/**
 * Returns a list of active users that match the search string and have all specified permissions for the project or issue.
 * This resource can be accessed by users with ADMINISTER_PROJECT permission for the project or global ADMIN or SYSADMIN rights.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-findUsersWithAllPermissions
 * @param options Request options.
 */
export declare function findUsersWithAllPermissions(options: User.Search.FindUsersWithAllPermissions.Options.RawApi): Promise<import("@avst-api/commons").Response<User.Search.FindUsersWithAllPermissions.Response.OK | undefined>>;
/**
 * Returns a list of users that match the search string. This resource cannot be accessed anonymously.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-findUsers
 * @param options Request options.
 */
export declare function findUsers(options: User.Search.FindUsers.Options.RawApi): Promise<import("@avst-api/commons").Response<User.Search.FindUsers.Response.OK | undefined>>;
/**
 * Returns a list of active users that match the search string. This resource cannot be accessed anonymously and requires the Browse Users global permission. Given an issue key this resource will provide a list of users that match the search string and have the browse issue permission for the issue provided.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/user-findUsersWithBrowsePermission
 * @param options Request options.
 */
export declare function findUsersWithBrowsePermission(options: User.Search.FindUsersWithBrowsePermission.Options.RawApi): Promise<import("@avst-api/commons").Response<User.Search.FindUsersWithBrowsePermission.Response.OK | undefined>>;
//# sourceMappingURL=search.d.ts.map