import { httpGet } from '../common';
/**
 * Returns a list of all statuses.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/status-getStatuses
 * @param options Request options.
 */
export function getWorkflowStatuses(options) {
    const { connectionId: instanceId, headers } = options;
    return httpGet(instanceId, '/rest/api/2/status', headers);
}
/**
 * Returns a full representation of the Status having the given id or name.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/status-getStatus
 * @param options Request options.
 */
export function getWorkflowStatus(options) {
    const { connectionId: instanceId, idOrName, headers } = options;
    return httpGet(instanceId, `/rest/api/2/status/${idOrName}`, headers);
}
