import { httpGet } from '../../common';
/**
 * Returns a list of all status categories.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/statuscategory-getStatusCategories
 * @param options Request options.
 */
export function getWorkflowStatusCategories(options) {
    const { connectionId: instanceId, headers } = options;
    return httpGet(instanceId, '/rest/api/2/statuscategory', headers);
}
/**
 * Returns a full representation of the StatusCategory having the given id or key.
 * Documentation: https://docs.atlassian.com/software/jira/docs/api/REST/7.13.9/#api/2/statuscategory-getStatusCategory
 * @param options Request options.
 */
export function getWorkflowStatusCategory(options) {
    const { connectionId: instanceId, idOrKey, headers } = options;
    return httpGet(instanceId, `/rest/api/2/statuscategory/${idOrKey}`, headers);
}
