import { CustomFieldSelectOption } from '../raw-api/common';
import { Issue } from '../types/issue';
import { User } from '../types/user';
import { Group } from '../types/group';
import { Project } from '../types/project';
import { FieldDetails } from '../definitions/field_details';
export interface CustomFieldsCollection {
    textFields: CustomFieldCollection<string>;
    numberFields: CustomFieldCollection<number>;
    multiSelectFields: CustomFieldCollection<CustomFieldSelectOption[]>;
    datePickerFields: CustomFieldCollection<string>;
    selectFields: CustomFieldCollection<CustomFieldSelectOption>;
    multiCheckboxesFields: CustomFieldCollection<CustomFieldSelectOption[]>;
    dateTimePickerFields: CustomFieldCollection<string>;
    labelsFields: CustomFieldCollection<string[]>;
    radioButtonsFields: CustomFieldCollection<CustomFieldSelectOption>;
    multiLineTextFields: CustomFieldCollection<string>;
    urlFields: CustomFieldCollection<string>;
    userPickerFields: CustomFieldCollection<User.GetUser.Response.OK>;
    globalRankFields: CustomFieldCollection<string>;
    multiGroupPickerFields: CustomFieldCollection<Group.CreateGroup.Response.OK[]>;
    groupPickerFields: CustomFieldCollection<Group.CreateGroup.Response.OK>;
    projectPickerFields: CustomFieldCollection<Project.GetProject.Response.OK>;
    readOnlyTextFields: CustomFieldCollection<string>;
    multiUserPickerFields: CustomFieldCollection<User.GetUser.Response.OK[]>;
    multiVersionPickerFields: CustomFieldCollection<Project.Version.GetVersion.Response.OK[]>;
    versionPickerFields: CustomFieldCollection<Project.Version.GetVersion.Response.OK>;
    epicColorFields: CustomFieldCollection<string>;
    epicStatusFields: CustomFieldCollection<Issue.Field.Custom.Option.GetOption.Response.OK>;
    epicLinkFields: CustomFieldCollection<string>;
    sprintFields: CustomFieldCollection<any>;
    epicNameFields: CustomFieldCollection<string>;
    cascadingSelectFields: CustomFieldCollection<any>;
}
export interface CustomField<T = any> {
    id: string;
    name: string;
    value: T;
}
export declare class CustomFieldReader implements CustomFieldsCollection {
    textFields: CustomFieldCollection<string>;
    numberFields: CustomFieldCollection<number>;
    multiSelectFields: CustomFieldCollection<CustomFieldSelectOption[]>;
    datePickerFields: CustomFieldCollection<string>;
    selectFields: CustomFieldCollection<CustomFieldSelectOption>;
    multiCheckboxesFields: CustomFieldCollection<CustomFieldSelectOption[]>;
    dateTimePickerFields: CustomFieldCollection<string>;
    labelsFields: CustomFieldCollection<string[]>;
    radioButtonsFields: CustomFieldCollection<CustomFieldSelectOption>;
    multiLineTextFields: CustomFieldCollection<string>;
    urlFields: CustomFieldCollection<string>;
    userPickerFields: CustomFieldCollection<import("../definitions/user").UserFull>;
    globalRankFields: CustomFieldCollection<string>;
    multiGroupPickerFields: CustomFieldCollection<import("../definitions/group").GroupResponse[]>;
    groupPickerFields: CustomFieldCollection<import("../definitions/group").GroupResponse>;
    projectPickerFields: CustomFieldCollection<import("../definitions/project").Project>;
    readOnlyTextFields: CustomFieldCollection<string>;
    multiUserPickerFields: CustomFieldCollection<import("../definitions/user").UserFull[]>;
    multiVersionPickerFields: CustomFieldCollection<import("../definitions/version").Version[]>;
    versionPickerFields: CustomFieldCollection<import("../definitions/version").Version>;
    epicColorFields: CustomFieldCollection<string>;
    epicStatusFields: CustomFieldCollection<Issue.Field.Custom.Option.GetOption.Response.OK>;
    epicLinkFields: CustomFieldCollection<string>;
    sprintFields: CustomFieldCollection<string[]>;
    epicNameFields: CustomFieldCollection<string>;
    cascadingSelectFields: CustomFieldCollection<any>;
    constructor(fields: FieldDetails[], issue: Issue.GetIssue.Response.OK);
    private extractFields;
    private processField;
    private getField;
}
export declare class CustomFieldCollection<T> {
    fields: CustomField<T>[];
    hasValue(customFieldIdOrName: number | string): boolean;
    /**
     * Returns custom field value by field ID or name, or undefined when value is not set
     */
    getValue(customFieldIdOrName: number | string): T | undefined;
    getFields(customFieldIdOrName: number | string): CustomField<T>[];
}
export declare class CustomFieldNotFound extends Error {
    message: string;
    name: string;
    constructor(message: string);
}
export declare class CustomFieldMultipleMatches extends Error {
    message: string;
    name: string;
    constructor(message: string);
}
//# sourceMappingURL=customField.d.ts.map