import { getFields } from '../raw-api/common';
export class CustomFieldReader {
    constructor(fields, issue) {
        this.textFields = new CustomFieldCollection();
        this.numberFields = new CustomFieldCollection();
        this.multiSelectFields = new CustomFieldCollection();
        this.datePickerFields = new CustomFieldCollection();
        this.selectFields = new CustomFieldCollection();
        this.multiCheckboxesFields = new CustomFieldCollection();
        this.dateTimePickerFields = new CustomFieldCollection();
        this.labelsFields = new CustomFieldCollection();
        this.radioButtonsFields = new CustomFieldCollection();
        this.multiLineTextFields = new CustomFieldCollection();
        this.urlFields = new CustomFieldCollection();
        this.userPickerFields = new CustomFieldCollection();
        this.globalRankFields = new CustomFieldCollection();
        this.multiGroupPickerFields = new CustomFieldCollection();
        this.groupPickerFields = new CustomFieldCollection();
        this.projectPickerFields = new CustomFieldCollection();
        this.readOnlyTextFields = new CustomFieldCollection();
        this.multiUserPickerFields = new CustomFieldCollection();
        this.multiVersionPickerFields = new CustomFieldCollection();
        this.versionPickerFields = new CustomFieldCollection();
        this.epicColorFields = new CustomFieldCollection();
        this.epicStatusFields = new CustomFieldCollection();
        this.epicLinkFields = new CustomFieldCollection();
        this.sprintFields = new CustomFieldCollection();
        this.epicNameFields = new CustomFieldCollection();
        this.cascadingSelectFields = new CustomFieldCollection();
        this.extractFields(fields, issue);
    }
    extractFields(fields, issue) {
        fields.forEach(field => {
            if (field.custom) {
                switch (field.schema.custom) {
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:textfield':
                        this.processField(this.textFields, field, issue);
                        break;
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:float':
                        this.processField(this.numberFields, field, issue);
                        break;
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:multiselect':
                        this.processField(this.multiSelectFields, field, issue);
                        break;
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:datepicker':
                        this.processField(this.datePickerFields, field, issue);
                        break;
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:select':
                        this.processField(this.selectFields, field, issue);
                        break;
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:multicheckboxes':
                        this.processField(this.multiCheckboxesFields, field, issue);
                        break;
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:datetime':
                        this.processField(this.dateTimePickerFields, field, issue);
                        break;
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:labels':
                        this.processField(this.labelsFields, field, issue);
                        break;
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:radiobuttons':
                        this.processField(this.radioButtonsFields, field, issue);
                        break;
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:textarea':
                        this.processField(this.multiLineTextFields, field, issue);
                        break;
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:url':
                        this.processField(this.urlFields, field, issue);
                        break;
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:userpicker':
                        this.processField(this.userPickerFields, field, issue);
                        break;
                    case 'com.pyxis.greenhopper.jira:gh-lexo-rank':
                        this.processField(this.globalRankFields, field, issue);
                        break;
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:multigrouppicker':
                        this.processField(this.multiGroupPickerFields, field, issue);
                        break;
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:grouppicker':
                        this.processField(this.groupPickerFields, field, issue);
                        break;
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:project':
                        this.processField(this.projectPickerFields, field, issue);
                        break;
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:readonlyfield':
                        this.processField(this.readOnlyTextFields, field, issue);
                        break;
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:multiuserpicker':
                        this.processField(this.multiUserPickerFields, field, issue);
                        break;
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:multiversion':
                        this.processField(this.multiVersionPickerFields, field, issue);
                        break;
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:version':
                        this.processField(this.versionPickerFields, field, issue);
                        break;
                    case 'com.pyxis.greenhopper.jira:gh-epic-color':
                        this.processField(this.epicColorFields, field, issue);
                        break;
                    case 'com.pyxis.greenhopper.jira:gh-epic-status':
                        this.processField(this.epicStatusFields, field, issue);
                        break;
                    case 'com.pyxis.greenhopper.jira:gh-epic-link':
                        this.processField(this.epicLinkFields, field, issue);
                        break;
                    case 'com.pyxis.greenhopper.jira:gh-sprint':
                        this.processField(this.sprintFields, field, issue);
                        break;
                    case 'com.pyxis.greenhopper.jira:gh-epic-label':
                        this.processField(this.epicNameFields, field, issue);
                        break;
                    case 'com.atlassian.jira.plugin.system.customfieldtypes:cascadingselect':
                        this.processField(this.cascadingSelectFields, field, issue);
                        break;
                }
            }
        });
    }
    processField(collection, field, issue) {
        const fieldValue = issue.fields[field.id];
        collection.fields.push(this.getField(field, fieldValue));
    }
    getField(field, value) {
        return {
            id: field.id,
            name: field.name,
            value
        };
    }
}
export class CustomFieldCollection {
    constructor() {
        this.fields = [];
    }
    hasValue(customFieldIdOrName) {
        return this.getFields(customFieldIdOrName).length > 0;
    }
    /**
     * Returns custom field value by field ID or name, or undefined when value is not set
     */
    getValue(customFieldIdOrName) {
        const fields = this.getFields(customFieldIdOrName);
        if (fields.length === 0) {
            throw new CustomFieldNotFound(`Custom field with name or ID '${customFieldIdOrName}' does not exist.`);
        }
        else if (fields.length === 1) {
            return fields[0].value;
        }
        else {
            throw new CustomFieldMultipleMatches(`Found too many matching custom field values with the same name '${customFieldIdOrName}', please consider using field ID instead`);
        }
    }
    getFields(customFieldIdOrName) {
        return getFields(this.fields, customFieldIdOrName);
    }
}
export class CustomFieldNotFound extends Error {
    constructor(message) {
        super(message);
        this.message = message;
        this.name = 'CustomFieldNotFound';
    }
}
export class CustomFieldMultipleMatches extends Error {
    constructor(message) {
        super(message);
        this.message = message;
        this.name = 'CustomFieldMultipleMatches';
    }
}
