import { ErrorStrategyOption, AssistedErrorStrategyOption } from '../handled-api/common';
import { HeadersOption, ConnectionOption } from '@avst-api/commons';
import { FilterPermission, Filter } from '../definitions/filter';
import { ColumnItem } from '../definitions/column_item';
export declare namespace Filter {
    namespace GetFilter {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = Filter;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                id: string | number;
                /**
                 * the parameters to expand
                 */
                expand?: string[];
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetMyFavouriteFilters {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = Filter[];
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                expand?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace CreateFilter {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = Filter;
        namespace Response {
            type OK = Filter;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                expand?: string;
                body: Filter.CreateFilter.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace EditFilter {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = Filter;
        namespace Response {
            type OK = Filter;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                id: string | number;
                expand?: string;
                body: Filter.EditFilter.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace DeleteFilter {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = undefined;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                id: string | number;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace Column {
        namespace GetDefaultColumns {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = ColumnItem[];
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    id: string | number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace SetDefaultColumns {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                columns: Array<string>;
            };
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    id: string | number;
                    body: Filter.Column.SetDefaultColumns.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace ResetColumns {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    id: string | number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace Share {
        namespace GetDefaultScope {
            interface Options extends HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    scope?: 'GLOBAL' | 'AUTHENTICATED' | 'PRIVATE';
                };
                type Error = undefined;
            }
            namespace Options {
                interface RawApi extends ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace SetDefaultScope {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                scope?: 'GLOBAL' | 'PRIVATE';
            };
            namespace Response {
                type OK = {
                    scope?: 'GLOBAL' | 'AUTHENTICATED' | 'PRIVATE';
                };
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    body: Filter.Share.SetDefaultScope.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace Permission {
            namespace GetSharePermission {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = FilterPermission;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        id: string | number;
                        permissionId: string | number;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace GetSharePermissions {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = FilterPermission[];
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        id: string | number;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace DeleteSharePermission {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = undefined;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        id: string | number;
                        permissionId: string | number;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace AddSharePermissions {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                type Body = {
                    projectId?: string;
                    projectRoleId?: string;
                    userKey?: string;
                    type?: string;
                    groupname?: string;
                    view: boolean;
                    edit: boolean;
                };
                namespace Response {
                    type OK = FilterPermission[];
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        id: string | number;
                        body: Filter.Share.Permission.AddSharePermissions.Body;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
        }
    }
}
//# sourceMappingURL=filter.d.ts.map