import { ErrorStrategyOption, AssistedErrorStrategyOption } from '../handled-api/common';
import { HeadersOption, ConnectionOption } from '@avst-api/commons';
import { GetUsersResponse, GroupResponse } from '../definitions/group';
export declare namespace Group {
    namespace CreateGroup {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * The name of the group to create.
             */
            name: string;
        };
        namespace Response {
            type OK = GroupResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                body: Group.CreateGroup.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace RemoveGroup {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = undefined;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * The name of the group to delete.
                 */
                groupname: string;
                /**
                 * If you delete a group and content is restricted to that group, the content will be hidden from all users. To prevent this, use this parameter to specify a different group to transfer the restrictions (comments and worklogs only) to.
                 */
                swapGroup?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace User {
        namespace GetUsers {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = GetUsersResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * a name of the group for which members will be returned.
                     */
                    groupname: string;
                    /**
                     * inactive users will be included in the response if set to true.
                     */
                    includeInactiveUsers?: boolean;
                    /**
                     * the index of the first user in group to return (0 based).
                     */
                    startAt?: number;
                    /**
                     * the maximum number of users to return (max 50).
                     */
                    maxResults?: number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace AddUsers {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                /**
                 * A name of the added user.
                 */
                name: string;
            };
            namespace Response {
                type OK = GroupResponse;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * A name of requested group.
                     */
                    groupname: string;
                    body: Group.User.AddUsers.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace RemoveUsers {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * A name of requested group.
                     */
                    groupname: string;
                    /**
                     * User to remove from a group
                     */
                    username: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
}
//# sourceMappingURL=group.d.ts.map