import { ErrorStrategyOption, AssistedErrorStrategyOption } from '../handled-api/common';
import { Property } from '../definitions/property';
import { HeadersOption, ConnectionOption } from '@avst-api/commons';
import { GetConfigurationResponse, GetInfoResponse } from '../definitions/instance';
export declare namespace Instance {
    namespace GetConfiguration {
        interface Options extends HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = GetConfigurationResponse;
            type Error = undefined;
        }
        namespace Options {
            interface RawApi extends ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetApplicationProperty {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = Property;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * a String containing the property key
                 */
                key?: string;
                /**
                 * when fetching a list specifies the permission level of all items in the list see {@link com.atlassian.jira.bc.admin.ApplicationPropertiesService.EditPermissionLevel}
                 */
                permissionLevel?: string;
                /**
                 * when fetching a list allows the list to be filtered by the property's start of key e.g. "jira.lf.*" whould fetch only those permissions that are editable and whose keys start with "jira.lf.". This is a regex.
                 */
                keyFilter?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace SetApplicationProperty {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            id: string;
            value: string;
        };
        namespace Response {
            type OK = Property;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                id: string;
                body: Instance.SetApplicationProperty.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetAdvancedSettings {
        interface Options extends HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = Property[];
            type Error = undefined;
        }
        namespace Options {
            interface RawApi extends ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetInfo {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = GetInfoResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                doHealthCheck?: boolean;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
}
//# sourceMappingURL=instance.d.ts.map