import { ErrorStrategyOption, AssistedErrorStrategyOption } from '../handled-api/common';
import { Attachment } from '../definitions/attachment';
import { HistoryMetadata } from '../definitions/history_metadata';
import { AvatarUrls } from '../definitions/avatarUrls';
import { JsonType } from '../definitions/json_type';
import { Comment } from '../definitions/comment';
import { RemoteIssueLink } from '../definitions/remote_issue_link';
import { UserPartial } from '../definitions/user';
import { Worklog } from '../definitions/worklog';
import { Transition } from '../definitions/transition';
import { Priority } from '../definitions/priority';
import { IssueRef } from '../definitions/issue_ref';
import { IssueType } from '../definitions/issue_type';
import { IssueLinkType } from '../definitions/issue_link_type';
import { Resolution } from '../definitions/resolution';
import { HeadersOption, ConnectionOption } from '@avst-api/commons';
import { EntityProperty, IdProperty, NameProperty, KeyProperty } from '../raw-api/common';
import { FieldsEditIssue, FieldsCreateIssue, IssueResponse } from '../definitions/issue';
import { FieldDetails } from '../definitions/field_details';
import { IssueBuilder } from '../builder/issue';
export declare namespace Issue {
    namespace CreateIssue {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = AssistedBodyFunction | {
            transition?: IdProperty;
            fields?: FieldsCreateIssue;
            update?: Record<string, {
                set?: any;
                edit?: any;
                add?: any;
                remove?: any;
            }>;
            historyMetadata?: HistoryMetadata;
            properties?: EntityProperty[];
            [x: string]: any;
        };
        type AssistedBodyFunction = (issueBuilder: IssueBuilder) => IssueBuilder | Issue.CreateIssue.Body;
        namespace Response {
            type OK = {
                id?: string;
                key?: string;
                self?: string;
            };
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                body: Issue.CreateIssue.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetIssue {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = IssueResponse;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                issueIdOrKey: string | number;
                /**
                 * The fields param (which can be specified multiple times) gives a comma-separated list of fields to include in the response. This can be used to retrieve a subset of fields. A particular field can be excluded by prefixing it with a minus.
                 * By default, all (*all) fields are returned in this get-issue resource. Note: the default is different when doing a jql search -- the default there is just navigable fields (*navigable).
                 ** *all - include all fields
                ** *navigable - include just navigable fields
                ** summary,comment - include just the summary and comments
                ** -comment - include everything except comments (the default is *all for get-issue)
                ** *all,-comment - include everything except comments
                */
                fields?: string;
                /**
                 * The expand param is used to include, hidden by default, parts of response. This can be used to include:
                 ** renderedFields - field values in HTML format
                ** names - display name of each field
                ** schema - schema for each field which describes a type of the field
                ** transitions - all possible transitions for the given issue
                ** operations - all possibles operations which may be applied on issue
                ** editmeta - information about how each field may be edited. It contains field's schema as well.
                ** changelog - history of all changes of the given issue
                ** versionedRepresentations - REST representations of all fields. Some field may contain more recent versions. RESET representations are numbered. The greatest number always represents the most recent version. It is recommended that the most recent version is used. version for these fields which provide a more recent REST representation. After including versionedRepresentations "fields" field become hidden.
                */
                expand?: string[];
                /**
                 * The properties param is similar to fields and specifies a comma-separated list of issue properties to include. Unlike fields, properties are not included by default. To include them all send ?properties=*all. You can also include only specified properties or exclude some properties with a minus (-) sign.
                 ** *all - include all properties
                ** *all, -prop1 - include all properties except prop1
                ** prop1, prop1 - include prop1 and prop2 properties
                */
                properties?: string;
                updateHistory?: boolean;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace DeleteIssue {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = undefined;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                issueIdOrKey: string | number;
                /**
                 * a String of true or false indicating that any subtasks should also be deleted. If the issue has no subtasks this parameter is ignored. If the issue has subtasks and this parameter is missing or false, then the issue will not be deleted and an error will be returned.
                 */
                deleteSubtasks?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace EditIssue {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = AssistedBodyFunction | {
            transition?: IdProperty;
            fields?: FieldsEditIssue;
            update?: Record<string, {
                set?: any;
                edit?: any;
                add?: any;
                remove?: any;
            }[]>;
            historyMetadata?: HistoryMetadata;
            properties?: EntityProperty[];
            [x: string]: any;
        };
        namespace Response {
            type OK = undefined;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                issueIdOrKey: string | number;
                /**
                 * send the email with notification that the issue was updated to users that watch it. Admin or project admin permissions are required to disable the notification.
                 */
                notifyUsers?: boolean;
                body: Issue.EditIssue.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
        type AssistedBodyFunction = (issueBuilder: IssueBuilder) => IssueBuilder | Issue.EditIssue.Body;
    }
    namespace SendNotification {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            subject?: string;
            textBody?: string;
            htmlBody?: string;
            to?: {
                reporter: boolean;
                assignee: boolean;
                watchers: boolean;
                voters: boolean;
                users?: NameProperty[];
                groups?: NameProperty[];
            };
            restrict?: {
                groups?: NameProperty[];
                permissions?: {
                    id?: string;
                    key?: string;
                }[];
            };
        };
        namespace Response {
            type OK = undefined;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                issueIdOrKey: string | number;
                body: Issue.SendNotification.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace AssignIssue {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            /**
             * name of the user
             */
            name: string;
        };
        namespace Response {
            type OK = undefined;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                issueIdOrKey: string | number;
                body: Issue.AssignIssue.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace Comment {
        namespace GetComments {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    startAt?: number;
                    maxResults?: number;
                    total?: number;
                    comments?: Comment[];
                };
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    issueIdOrKey: string | number;
                    /**
                     * the page offset, if not specified then defaults to 0
                     */
                    startAt?: number;
                    /**
                     * how many results on the page should be included. Defaults to 50.
                     */
                    maxResults?: number;
                    /**
                     * ordering of the results.
                     */
                    orderBy?: '-created' | 'created' | '+created';
                    /**
                     * optional flags: renderedBody (provides body rendered in HTML)
                     */
                    expand?: string[];
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace AddComment {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                body?: string;
                visibility?: {
                    type?: 'group' | 'role';
                    value?: string;
                };
            };
            namespace Response {
                type OK = Comment;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    issueIdOrKey: string | number;
                    /**
                     * optional flags: renderedBody (provides body rendered in HTML)
                     */
                    expand?: string[];
                    body: Issue.Comment.AddComment.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetComment {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = Comment;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    issueIdOrKey: string | number;
                    id: string;
                    /**
                     * optional flags: renderedBody (provides body rendered in HTML)
                     */
                    expand?: string[];
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace UpdateComment {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                body?: string;
                visibility?: {
                    type?: 'group' | 'role';
                    value?: string;
                };
            };
            namespace Response {
                type OK = Comment;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    issueIdOrKey: string | number;
                    id: string;
                    /**
                     * optional flags: renderedBody (provides body rendered in HTML)
                     */
                    expand?: string[];
                    body: Issue.Comment.UpdateComment.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace DeleteComment {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    issueIdOrKey: string | number;
                    id: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace Metadata {
        namespace GetEditMetadata {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    fields?: Record<string, {
                        required: boolean;
                        schema?: JsonType;
                        name?: string;
                        autoCompleteUrl?: string;
                        hasDefaultValue?: boolean;
                        operations?: string[];
                        allowedValues?: any[];
                    }>;
                };
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    issueIdOrKey: string | number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetCreateMetadata {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    expand?: string;
                    projects?: {
                        expand?: string;
                        self?: string;
                        id?: string;
                        key?: string;
                        name?: string;
                        avatarUrls?: AvatarUrls;
                        issuetypes: {
                            subtask: boolean;
                            self?: string;
                            id?: string;
                            description?: string;
                            iconUrl?: string;
                            name?: string;
                            avatarId?: string;
                            expand?: string;
                            fields?: Record<string, {
                                required: boolean;
                                schema?: JsonType;
                                name?: string;
                                autoCompleteUrl?: string;
                                hasDefaultValue?: boolean;
                                operations?: string[];
                                allowedValues?: any[];
                            }>;
                        }[];
                    }[];
                };
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * combined with the projectKeys param, lists the projects with which to filter the results. If absent, all projects are returned. This parameter can be specified multiple times, and/or be a comma-separated list. Specifiying a project that does not exist (or that you cannot create issues in) is not an error, but it will not be in the results.
                     */
                    projectIds?: string;
                    /**
                     * combined with the projectIds param, lists the projects with which to filter the results. If null, all projects are returned. This parameter can be specified multiple times, and/or be a comma-separated list. Specifiying a project that does not exist (or that you cannot create issues in) is not an error, but it will not be in the results.
                     */
                    projectKeys?: string;
                    /**
                     * combinded with issuetypeNames, lists the issue types with which to filter the results. If null, all issue types are returned. This parameter can be specified multiple times, and/or be a comma-separated list. Specifiying an issue type that does not exist is not an error.
                     */
                    issuetypeIds?: string;
                    /**
                     * combinded with issuetypeIds, lists the issue types with which to filter the results. If null, all issue types are returned. This parameter can be specified multiple times, but is NOT interpreted as a comma-separated list. Specifiying an issue type that does not exist is not an error.
                     */
                    issuetypeNames?: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace Vote {
        namespace RemoveVote {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    issueIdOrKey: string | number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace AddVote {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    issueIdOrKey: string | number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetVotes {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    votes: number;
                    hasVoted: boolean;
                    self?: string;
                    voters?: UserPartial[];
                };
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    issueIdOrKey: string | number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace Watcher {
        namespace GetWatchers {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    watchCount: number;
                    self?: string;
                    isWatching?: boolean;
                    watchers?: UserPartial[];
                };
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    issueIdOrKey: string | number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace AddWatcher {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    issueIdOrKey: string | number;
                    /**
                     * User's name
                     */
                    body: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace RemoveWatcher {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    issueIdOrKey: string | number;
                    /**
                     * a String containing the name of the user to remove from the watcher list. Must not be null.
                     */
                    username: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace Worklog {
        namespace GetWorklogs {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    startAt?: number;
                    maxResults?: number;
                    total?: number;
                    worklogs?: Worklog[];
                };
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    issueIdOrKey: string | number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace AddWorklog {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                comment?: string;
                visibility?: {
                    type?: 'group' | 'role';
                    value?: string;
                };
                started?: string;
                timeSpent?: string;
                timeSpentSeconds?: number;
            };
            namespace Response {
                type OK = Worklog;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    issueIdOrKey: string | number;
                    /**
                     * (optional) allows you to provide specific instructions to update the remaining time estimate of the issue.
                     * "new" - sets the estimate to a specific value
                     * "leave"- leaves the estimate as is
                     * "manual" - specify a specific amount to increase remaining estimate by
                     * "auto"- Default option. Will automatically adjust the value based on the new timeSpent specified on the worklog
                     */
                    adjustEstimate?: 'new' | 'leave' | 'manual' | 'auto';
                    /**
                     * (required when "new" is selected for adjustEstimate) the new value for the remaining estimate field. e.g. "2d"
                     */
                    newEstimate?: string;
                    /**
                     * (required when "manual" is selected for adjustEstimate) the amount to reduce the remaining estimate by e.g. "2d"
                     */
                    reduceBy?: string;
                    body: Issue.Worklog.AddWorklog.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetWorklog {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = Worklog;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    issueIdOrKey: string | number;
                    id: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace UpdateWorklog {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                comment?: string;
                visibility?: {
                    type?: 'group' | 'role';
                    value?: string;
                };
                started?: string;
                timeSpent?: string;
                timeSpentSeconds?: number;
            };
            namespace Response {
                type OK = Worklog;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    issueIdOrKey: string | number;
                    id: string;
                    /**
                     * (optional) allows you to provide specific instructions to update the remaining time estimate of the issue.
                     * "new" - sets the estimate to a specific value
                     * "leave"- leaves the estimate as is
                     * "auto"- Default option. Will automatically adjust the value based on the new timeSpent specified on the worklog
                     */
                    adjustEstimate?: 'new' | 'leave' | 'auto';
                    /**
                     * (required when "new" is selected for adjustEstimate) the new value for the remaining estimate field. e.g. "2d"
                     */
                    newEstimate?: string;
                    body: Issue.Worklog.UpdateWorklog.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace DeleteWorklog {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    issueIdOrKey: string | number;
                    id: string;
                    /**
                     * (optional) allows you to provide specific instructions to update the remaining time estimate of the issue.
                     * "new" - sets the estimate to a specific value
                     * "leave"- leaves the estimate as is
                     * "manual" - specify a specific amount to increase remaining estimate by
                     * "auto"- Default option. Will automatically adjust the value based on the new timeSpent specified on the worklog
                     */
                    adjustEstimate?: 'new' | 'leave' | 'manual' | 'auto';
                    /**
                     * (required when "new" is selected for adjustEstimate) the new value for the remaining estimate field. e.g. "2d"
                     */
                    newEstimate?: string;
                    /**
                     * (required when "manual" is selected for adjustEstimate) the amount to increase the remaining estimate by e.g. "2d"
                     */
                    increaseBy?: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetDeletedWorklogIds {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    lastPage: boolean;
                    values?: {
                        worklogId?: number;
                        updatedTime?: number;
                    }[];
                    since?: number;
                    until?: number;
                    self?: string;
                    nextPage?: string;
                };
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * a date time in unix timestamp format since when deleted worklogs will be returned.
                     */
                    since?: number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetWorklogsForIds {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                ids: number[];
            };
            namespace Response {
                type OK = Worklog[];
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    body: Issue.Worklog.GetWorklogsForIds.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetUpdatedWorklogIds {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    lastPage: boolean;
                    values?: {
                        worklogId?: number;
                        updatedTime?: number;
                    }[];
                    since?: number;
                    until?: number;
                    self?: string;
                    nextPage?: string;
                };
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * a date time in unix timestamp format since when updated worklogs will be returned.
                     */
                    since?: number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace Transition {
        namespace GetTransitions {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    expand?: string;
                    transitions?: Transition[];
                };
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    issueIdOrKey: string | number;
                    transitionId?: string;
                    expand?: string[];
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace PerformTransition {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                transition?: IdProperty;
                fields?: FieldsEditIssue;
                update?: Record<string, {
                    set?: any;
                    edit?: any;
                    add?: any;
                    remove?: any;
                }[]>;
                historyMetadata?: HistoryMetadata;
                properties?: EntityProperty[];
            };
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    issueIdOrKey: string | number;
                    body: Issue.Transition.PerformTransition.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace SubTask {
        namespace GetSubTasks {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = IssueRef[];
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    issueIdOrKey: string | number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace CanMoveSubTask {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = boolean;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    issueIdOrKey: string | number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace MoveSubTasks {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                current: number;
                original: number;
            };
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    issueIdOrKey: string | number;
                    body: Issue.SubTask.MoveSubTasks.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace Link {
        namespace CreateLink {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                type?: NameProperty | IdProperty;
                inwardIssue?: KeyProperty | IdProperty;
                outwardIssue?: KeyProperty | IdProperty;
                comment?: {
                    body?: string;
                    visibility?: {
                        type?: 'group' | 'role';
                        value?: string;
                    };
                };
            };
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    body: Issue.Link.CreateLink.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetLink {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    id?: string;
                    self?: string;
                    type?: IssueLinkType;
                    inwardIssue?: IssueRef;
                    outwardIssue?: IssueRef;
                };
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    linkId: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace DeleteLink {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    linkId: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace Type {
            namespace GetTypes {
                interface Options extends HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = {
                        issueLinkTypes?: IssueLinkType[];
                    };
                    type Error = undefined;
                }
                namespace Options {
                    interface RawApi extends ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace GetType {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = IssueLinkType;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        issueLinkTypeId: string;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace CreateType {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                type Body = IssueLinkType;
                namespace Response {
                    type OK = IssueLinkType;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        body: Issue.Link.Type.CreateType.Body;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace DeleteType {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = undefined;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        issueLinkTypeId: string;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace UpdateType {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                type Body = IssueLinkType;
                namespace Response {
                    type OK = IssueLinkType;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        issueLinkTypeId: string;
                        body: Issue.Link.Type.UpdateType.Body;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
        }
        namespace Remote {
            namespace GetLinks {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = (RemoteIssueLink & {
                        id?: number;
                        self?: string;
                    })[];
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        issueIdOrKey: string | number;
                        /**
                         * The id of the remote issue link to be returned. If null (not provided) all remote links for the issue are returned.
                         */
                        globalId?: string;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace CreateOrUpdateLink {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                type Body = RemoteIssueLink;
                namespace Response {
                    type OK = {
                        id?: number;
                        self?: string;
                    };
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        issueIdOrKey: string | number;
                        /**
                         * If a globalId is provided and a remote issue link exists with that globalId, the remote issue link is updated. Otherwise, the remote issue link is created.
                         */
                        body: Issue.Link.Remote.CreateOrUpdateLink.Body;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace DeleteLinkByGlobalId {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = undefined;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        issueIdOrKey: string | number;
                        /**
                         * the global id of the remote issue link
                         */
                        globalId: string;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace GetLink {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = RemoteIssueLink & {
                        id?: number;
                        self?: string;
                    };
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        issueIdOrKey: string | number;
                        linkId: string;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace UpdateLink {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                type Body = RemoteIssueLink;
                namespace Response {
                    type OK = undefined;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        issueIdOrKey: string | number;
                        linkId: string;
                        body: Issue.Link.Remote.UpdateLink.Body;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace DeleteLink {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = undefined;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        issueIdOrKey: string | number;
                        linkId: string;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
        }
    }
    namespace Field {
        namespace GetFields {
            interface Options extends HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = FieldDetails[];
                type Error = undefined;
            }
            namespace Options {
                interface RawApi extends ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace Custom {
            namespace GetFields {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = {
                        maxResults: number;
                        startAt: number;
                        self?: string;
                        nextPage?: string;
                        total?: number;
                        isLast?: boolean;
                        values?: {
                            isLocked: boolean;
                            isManaged: boolean;
                            isAllProjects: boolean;
                            projectsCount: number;
                            screensCount: number;
                            id?: string;
                            name?: string;
                            description?: string;
                            type?: string;
                            searcherKey?: string;
                            self?: string;
                            numericId?: number;
                        }[];
                    };
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        /**
                         * Default: 1
                         */
                        startAt?: number;
                        /**
                         * Default: 50
                         */
                        maxResults?: number;
                        search?: string;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace Option {
                namespace GetOption {
                    interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                    }
                    namespace Response {
                        type OK = {
                            self?: string;
                            value?: string;
                        };
                        type Error = undefined;
                    }
                    namespace Options {
                        interface Base {
                            id: string;
                        }
                        interface RawApi extends Base, ConnectionOption, HeadersOption {
                        }
                        interface HandledApi extends RawApi, ErrorStrategyOption {
                        }
                    }
                }
            }
        }
    }
    namespace Attachment {
        namespace GetAttachment {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = Attachment;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    id: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace RemoveAttachment {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    id: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace AddAttachment {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                fileName: string;
                content: string | ArrayBuffer;
            };
            namespace Response {
                type OK = Attachment[];
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    issueIdOrKey: string | number;
                    body: Issue.Attachment.AddAttachment.Body[];
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace Metadata {
            namespace GetMetadata {
                interface Options extends HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = {
                        enabled: boolean;
                        uploadLimit?: number;
                    };
                    type Error = undefined;
                }
                namespace Options {
                    interface RawApi extends ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
        }
    }
    namespace Type {
        namespace GetTypes {
            interface Options extends HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = IssueType[];
                type Error = undefined;
            }
            namespace Options {
                interface RawApi extends ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetType {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = IssueType;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    id: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace CreateType {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                name?: string;
                description?: string;
                type?: 'subask' | 'standard';
            };
            namespace Response {
                type OK = IssueType;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    body: Issue.Type.CreateType.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace DeleteType {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    id: string | number;
                    alternativeIssueTypeId?: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace UpdateType {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                name?: string;
                description?: string;
                avatarId?: number;
            };
            namespace Response {
                type OK = IssueType;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    id: string | number;
                    body: Issue.Type.UpdateType.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetAlternativeTypes {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = IssueType[];
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    id: string | number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace Priority {
        namespace GetPriorities {
            interface Options extends HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = Priority[];
                type Error = undefined;
            }
            namespace Options {
                interface RawApi extends ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetPriority {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = Priority;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    id: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace Resolution {
        namespace GetResolutions {
            interface Options extends HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = Resolution[];
                type Error = undefined;
            }
            namespace Options {
                interface RawApi extends ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetResolution {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = Resolution;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    id: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace Search {
        namespace SearchByJql {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                jql?: string;
                startAt?: number;
                maxResults?: number;
                fields?: string[];
                validateQuery?: boolean;
            };
            namespace Response {
                type OK = {
                    expand?: string;
                    startAt?: number;
                    maxResults?: number;
                    total?: number;
                    issues?: IssueResponse[];
                    warningMessages?: string[];
                    names?: Record<string, string>;
                    schema?: Record<string, JsonType>;
                };
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    body: Issue.Search.SearchByJql.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
}
//# sourceMappingURL=issue.d.ts.map