import { ErrorStrategyOption, AssistedErrorStrategyOption } from '../handled-api/common';
import { Component } from '../definitions/component';
import { HeadersOption, ConnectionOption } from '@avst-api/commons';
import { Project } from '../definitions/project';
import { Status } from '../definitions/status';
import { Version } from '../definitions/version';
import { ProjectRole } from '../definitions/project_role';
import { ProjectType } from '../definitions/project_type';
import { SimpleLink } from '../definitions/simple_link';
export declare namespace Project {
    namespace GetProjects {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = Project[];
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * the parameters to expand
                 */
                expand?: string[];
                /**
                 * if this parameter is set then only projects recently accessed by the current user (if not logged in then based on HTTP session) will be returned (maximum count limited to the specified number but no more than 20).
                 */
                recent?: number;
                /**
                 * whether to include archived projects in response, default: false
                 */
                includeArchived?: boolean;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace CreateProject {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            key: string;
            name: string;
            projectTypeKey: string;
            projectTemplateKey: string;
            lead: string;
            description?: string;
            url?: string;
            assigneeType?: 'PROJECT_LEAD' | 'UNASSIGNED';
            avatarId?: number;
            issueSecurityScheme?: number;
            permissionScheme?: number;
            notificationScheme?: number;
            categoryId?: number;
        };
        namespace Response {
            type OK = {
                self?: string;
                id?: number;
                key?: string;
            };
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                body: Project.CreateProject.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetProject {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = Project;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * the parameters to expand
                 */
                expand?: string[];
                projectIdOrKey: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace UpdateProject {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            key?: string;
            name?: string;
            description?: string;
            lead?: string;
            url?: string;
            assigneeType?: 'PROJECT_LEAD' | 'UNASSIGNED';
            avatarId?: number;
            issueSecurityScheme?: number;
            permissionScheme?: number;
            notificationScheme?: number;
            categoryId?: number;
        };
        namespace Response {
            type OK = Project;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * the parameters to expand in returned project
                 */
                expand?: string[];
                projectIdOrKey: string;
                body: Project.UpdateProject.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace DeleteProject {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = undefined;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                projectIdOrKey: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace ArchiveProject {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = undefined;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                projectIdOrKey: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetComponents {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = Component[];
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                projectIdOrKey: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace RestoreProject {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = undefined;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                projectIdOrKey: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetStatuses {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                subtask: boolean;
                self?: string;
                id?: string;
                name?: string;
                statuses?: Status[];
            };
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                projectIdOrKey: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace UpdateProjectType {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = Project;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                projectIdOrKey: string;
                newProjectTypeKey: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetVersionsPaginated {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = {
                maxResults: number;
                startAt: number;
                self?: string;
                nextPage?: string;
                total?: number;
                isLast?: boolean;
                values?: Version[];
            };
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                projectIdOrKey: string;
                /**
                 * the page offset, if not specified then defaults to 0
                 */
                startAt?: number;
                /**
                 * how many results on the page should be included. Defaults to 50.
                 */
                maxResults?: number;
                /**
                 * ordering of the results.
                 */
                orderBy?: '-sequence' | 'sequence' | '+sequence' | '-name' | 'name' | '+name' | '-startDate' | 'startDate' | '+startDate' | '-releaseDate' | 'releaseDate' | '+sequence';
                /**
                 * the parameters to expand
                 */
                expand?: string[];
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace GetVersions {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = Version[];
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                projectIdOrKey: string;
                /**
                 * the parameters to expand
                 */
                expand?: string[];
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace Component {
        namespace CreateComponent {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                name?: string;
                description?: string;
                leadUserName?: string;
                assigneeType?: 'PROJECT_DEFAULT' | 'COMPONENT_LEAD' | 'PROJECT_LEAD' | 'UNASSIGNED';
                project?: string;
            };
            namespace Response {
                type OK = Component;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    body: Project.Component.CreateComponent.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetComponent {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = Component;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    id: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace UpdateComponent {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                name?: string;
                description?: string;
                leadUserName?: string;
                assigneeType?: 'PROJECT_DEFAULT' | 'COMPONENT_LEAD' | 'PROJECT_LEAD' | 'UNASSIGNED';
                project?: string;
            };
            namespace Response {
                type OK = Component;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    id: string;
                    body: Project.Component.UpdateComponent.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace DeleteComponent {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    id: string;
                    /**
                     * The new component applied to issues whose 'id' component will be deleted. If this value is null, then the 'id' component is simply removed from the related isues.
                     */
                    moveIssuesTo?: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetRelatedIssues {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    issueCount: number;
                    self?: string;
                };
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    id: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace Role {
        namespace GetRoles {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = Record<string, string>;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    projectIdOrKey: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetRole {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = ProjectRole;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    projectIdOrKey: string;
                    id: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace Actor {
            namespace SetActors {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                type Body = {
                    categorisedActors: {
                        'atlassian-user-role-actor'?: string[];
                        'atlassian-group-role-actor'?: string[];
                    };
                };
                namespace Response {
                    type OK = ProjectRole;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        projectIdOrKey: string;
                        id: string;
                        body: Project.Role.Actor.SetActors.Body;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace AddUsers {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                type Body = {
                    user?: string[];
                    group?: string[];
                };
                namespace Response {
                    type OK = ProjectRole;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        projectIdOrKey: string;
                        id: string;
                        body: Project.Role.Actor.AddUsers.Body;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace DeleteActor {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = undefined;
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        projectIdOrKey: string;
                        id: string;
                        /**
                         * the username to remove from the project role
                         */
                        user?: string;
                        /**
                         * the groupname to remove from the project role
                         */
                        group?: string;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
        }
    }
    namespace Type {
        namespace GetTypes {
            interface Options extends HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = ProjectType[];
                type Error = undefined;
            }
            namespace Options {
                interface RawApi extends ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetType {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = ProjectType;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    projectTypeKey: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetAccessibleType {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = ProjectType;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    projectTypeKey: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace Validation {
        namespace ValidateProjectKey {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = {
                    errorMessages?: string[];
                    errors?: Record<string, string>;
                    status?: number;
                };
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * the project key
                     */
                    key: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
    namespace Version {
        namespace CreateVersion {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                name: string;
                description?: string;
                archived?: boolean;
                released?: boolean;
                /**
                 * Format: DD/MMM/YYYY
                 */
                userStartDate?: string;
                /**
                 * Format: DD/MMM/YYYY
                 */
                userReleaseDate?: string;
                /**
                 * Either this or projectId is required.
                 */
                project?: string;
                /**
                 * Either this or project is required.
                 */
                projectId?: number;
                operations?: SimpleLink[];
                remotelinks?: {
                    name?: string;
                    link?: any;
                }[];
            };
            namespace Response {
                type OK = Version;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    body: Project.Version.CreateVersion.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace MoveVersion {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                /**
                 * A version to place this version after. The value should be the self link of another version
                 */
                after?: string;
                /**
                 * An absolute position, which may have a value of 'First', 'Last', 'Earlier' or 'Later'
                 */
                position?: 'Earlier' | 'Later' | 'First' | 'Last';
            };
            namespace Response {
                type OK = Version;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    id: string;
                    body: Project.Version.MoveVersion.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace GetVersion {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = Version;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    id: string;
                    expand?: string[];
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace UpdateVersion {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = {
                description?: string;
                name?: string;
                archived?: boolean;
                released?: boolean;
                /**
                 * Format: DD/MMM/YYYY
                 */
                userStartDate?: string;
                /**
                 * Format: DD/MMM/YYYY
                 */
                userReleaseDate?: string;
                moveUnfixedIssuesTo?: string;
                operations?: SimpleLink[];
                remotelinks?: {
                    name?: string;
                    link?: any;
                }[];
            };
            namespace Response {
                type OK = Version;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    id: string;
                    body: Project.Version.UpdateVersion.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace DeleteVersion {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    id: string;
                    /**
                     * The version to set fixVersion to on issues where the deleted version is the fix version, If null then the fixVersion is removed.
                     */
                    moveFixIssuesTo?: string;
                    /**
                     * The version to set affectedVersion to on issues where the deleted version is the affected version, If null then the affectedVersion is removed.
                     */
                    moveAffectedIssuesTo?: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace MergeVersion {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    id: string;
                    moveIssuesTo: string;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace RemoveAndReplaceVersion {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            type Body = any;
            namespace Response {
                type OK = undefined;
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    id: string;
                    body: Project.Version.RemoveAndReplaceVersion.Body;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace Count {
            namespace GetVersionRelatedIssueCount {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = {
                        issuesFixedCount: number;
                        issuesAffectedCount: number;
                        issueCountWithCustomFieldsShowingVersion: number;
                        self?: string;
                        customFieldUsage?: {
                            customFieldId: number;
                            issueCountWithVersionInCustomField: number;
                            fieldName?: string;
                        }[];
                    };
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        id: string;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
            namespace GetVersionUnresolvedIssueCount {
                interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
                }
                namespace Response {
                    type OK = {
                        issuesUnresolvedCount: number;
                        self?: string;
                    };
                    type Error = undefined;
                }
                namespace Options {
                    interface Base {
                        id: string;
                    }
                    interface RawApi extends Base, ConnectionOption, HeadersOption {
                    }
                    interface HandledApi extends RawApi, ErrorStrategyOption {
                    }
                }
            }
        }
    }
}
//# sourceMappingURL=project.d.ts.map