import { ErrorStrategyOption, AssistedErrorStrategyOption } from '../handled-api/common';
import { HeadersOption, ConnectionOption } from '@avst-api/commons';
import { UserFull } from '../definitions/user';
export declare namespace User {
    namespace GetUser {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = UserFull;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * the username
                 */
                username?: string;
                /**
                 * user key
                 */
                key?: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace UpdateUser {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            name?: string;
            emailAddress?: string;
            displayName?: string;
        };
        namespace Response {
            type OK = UserFull;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * the username
                 */
                username?: string;
                /**
                 * user key
                 */
                key?: string;
                body: User.UpdateUser.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace CreateUser {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            name: string;
            emailAddress: string;
            displayName: string;
            password?: string;
            notification?: string;
            applicationKeys?: string[];
        };
        namespace Response {
            type OK = UserFull;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                body: User.CreateUser.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace RemoveUser {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = undefined;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * the username
                 */
                username: string;
                /**
                 * user key
                 */
                key: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace AddUserToApplication {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = undefined;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * username
                 */
                username: string;
                /**
                 * application key
                 */
                applicationKey: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace RemoveUserFromApplication {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        namespace Response {
            type OK = undefined;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * username
                 */
                username: string;
                /**
                 * application key
                 */
                applicationKey: string;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace ChangeUserPassword {
        interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
        }
        type Body = {
            password: string;
            currentPassword: string;
        };
        namespace Response {
            type OK = undefined;
            type Error = undefined;
        }
        namespace Options {
            interface Base {
                /**
                 * the username
                 */
                username?: string;
                /**
                 * user key
                 */
                key?: string;
                body: User.ChangeUserPassword.Body;
            }
            interface RawApi extends Base, ConnectionOption, HeadersOption {
            }
            interface HandledApi extends RawApi, ErrorStrategyOption {
            }
        }
    }
    namespace Search {
        namespace FindAssignableUsers {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = UserFull[];
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * the username
                     */
                    username?: string;
                    /**
                     * the key of the project we are finding assignable users for
                     */
                    project?: string;
                    /**
                     * the issue key for the issue being edited we need to find assignable users for.
                     */
                    issueKey?: string;
                    /**
                     * the index of the first user to return (0-based)
                     */
                    startAt?: number;
                    /**
                     * the maximum number of users to return (defaults to 50). The maximum allowed value is 1000. If you specify a value that is higher than this number, your search results will be truncated.
                     */
                    maxResults?: number;
                    actionDescriptorId?: number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace FindUsersWithAllPermissions {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = UserFull[];
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * comma separated list of permissions for project or issue returned users must have, see Permissions JavaDoc for the list of all possible permissions.
                     */
                    permissions: string;
                    /**
                     * the username filter, list includes all users if unspecified
                     */
                    username?: string;
                    /**
                     * the issue key for the issue for which returned users have specified permissions.
                     */
                    issueKey?: string;
                    /**
                     * the optional project key to search for users with if no issueKey is supplied.
                     */
                    projectKey?: string;
                    /**
                     * the index of the first user to return (0-based)
                     */
                    startAt?: number;
                    /**
                     * the maximum number of users to return (defaults to 50). The maximum allowed value is 1000. If you specify a value that is higher than this number, your search results will be truncated.
                     */
                    maxResults?: number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace FindUsers {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = UserFull[];
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * A query string used to search username, name or e-mail address
                     */
                    username: string;
                    /**
                     * the index of the first user to return (0-based)
                     */
                    startAt?: number;
                    /**
                     * the maximum number of users to return (defaults to 50). The maximum allowed value is 1000. If you specify a value that is higher than this number, your search results will be truncated.
                     */
                    maxResults?: number;
                    /**
                     * If true, then active users are included in the results (default true)
                     */
                    includeActive?: boolean;
                    /**
                     * If true, then inactive users are included in the results (default false)
                     */
                    includeInactive?: boolean;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
        namespace FindUsersWithBrowsePermission {
            interface Options extends Options.Base, HeadersOption, AssistedErrorStrategyOption {
            }
            namespace Response {
                type OK = UserFull[];
                type Error = undefined;
            }
            namespace Options {
                interface Base {
                    /**
                     * the username filter, no users returned if left blank
                     */
                    username: string;
                    /**
                     * the issue key for the issue being edited we need to find viewable users for.
                     */
                    issueKey?: string;
                    /**
                     * the optional project key to search for users with if no issueKey is supplied.
                     */
                    projectKey?: string;
                    /**
                     * the index of the first user to return (0-based)
                     */
                    startAt?: number;
                    /**
                     * the maximum number of users to return (defaults to 50). The maximum allowed value is 1000. If you specify a value that is higher than this number, your search results will be truncated.
                     */
                    maxResults?: number;
                }
                interface RawApi extends Base, ConnectionOption, HeadersOption {
                }
                interface HandledApi extends RawApi, ErrorStrategyOption {
                }
            }
        }
    }
}
//# sourceMappingURL=user.d.ts.map